(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    301734,       7176]
NotebookOptionsPosition[    288008,       6938]
NotebookOutlinePosition[    290192,       7010]
CellTagsIndexPosition[    290149,       7007]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["CustomTicks package",
  FontFamily->"Times New Roman",
  FontSize->36],
 StyleBox["\n",
  FontFamily->"Times New Roman"],
 StyleBox["Mark A. Caprio, Department of Physics, University of Notre Dame", 
  "SmallText",
  FontFamily->"Times New Roman",
  FontSize->12],
 "\nVersion 2.1.1 (August 26, 2020) "
}], "Text",
 CellFrame->{{0, 0}, {2, 0}},
 CellChangeTimes->{{3.4247304725625*^9, 3.424730482609375*^9}, {
   3.42585660284375*^9, 3.425856606109375*^9}, {3.431818235890625*^9, 
   3.431818240796875*^9}, {3.516133792453125*^9, 3.516133799984375*^9}, {
   3.5264206845625*^9, 3.526420694140625*^9}, {3.566838279130357*^9, 
   3.566838285018366*^9}, {3.6141979980079308`*^9, 3.6141980022199383`*^9}, {
   3.6142013749739585`*^9, 3.6142013863339744`*^9}, {3.6216273119876413`*^9, 
   3.621627313282443*^9}, 3.6216279493535705`*^9, {3.666800251973149*^9, 
   3.6668002625499673`*^9}, {3.807479717204237*^9, 3.8074797287955008`*^9}},
 Hyphenation->False,ExpressionUUID->"b9a012dc-af07-482b-bdc9-9fc3e04818b2"],

Cell["\<\
Notebook notes:
\tStyleSheet is HelpBrowser.
\tNotebook options: \"Cell Options\">>\"Display Options\">>\"Cell Element \
Spacings\">>\"ClosedCellHeight\"->1
\tHyphenation: LanguageCategory set to None is supposed to prevent \
hyphenation but does not seem to work as advertised.  Setting Hyphenation to \
None also fails.  Each cell's Hyphenation option must be set to None.
\tBefore distribution: update version number in footer, convert all -> to \
\[Rule] in running text; set AppendTo directory argument to c:\\\\example, \
select all cells and set \"Formatting Options\">>\"Text Layout\">>Hyphenation \
to None; unset options Editable and Deletable
\t
\tInitialization:
\tGet[\[OpenCurlyDoubleQuote]LevelScheme`MCText`\[CloseCurlyDoubleQuote]]\
\>", "Text",
 CellOpen->False,
 CellChangeTimes->{{3.807481497376482*^9, 3.8074815015811357`*^9}},
 Hyphenation->False,ExpressionUUID->"06a94110-0c96-4d64-a2ae-97e3c532bfa3"],

Cell[CellGroupData[{

Cell["Introduction", "Subsubsection",ExpressionUUID->"c05faaf6-6435-4d7b-9f90-d9033ebf040b"],

Cell[TextData[{
 "\t",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " provides a powerful system for generating graphics but does not provide, \
in built-in form, the fine formatting control necessary for the preparation \
of publication quality figures.  The CustomTicks package provides detailed \
customization of tick mark placement and formatting.  The flexibility \
achieved matches or exceeds that available with most commercial scientific \
plotting software.  Linear, logarithmic, and general nonlinear axes are \
supported.  Some tick mark manipulation functions, for use in graphics \
programming, are also provided by the CustomTicks package."
}], "Text",ExpressionUUID->"4675df0d-1e1b-42c3-b297-afd05360a993"],

Cell[TextData[{
 "\tThe CustomTicks package is part of the SciDraw system for preparing \
publication-quality scientific figures with ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " (",
 StyleBox["http://scidraw.nd.edu",
  FontFamily->"Courier New"],
 ").  It was originally developed as part of LevelScheme [Comput. Phys. \
Commun. ",
 StyleBox["171",
  FontWeight->"Bold"],
 ", 107 (2005)]."
}], "Text",
 CellChangeTimes->{
  3.51613434028125*^9, {3.6216273183680525`*^9, 3.6216275211234136`*^9}, {
   3.8074809166431303`*^9, 3.8074809240648117`*^9}, {3.807480981207466*^9, 
   3.807481004487377*^9}, {3.8074810443517847`*^9, 3.8074810618400803`*^9}, 
   3.8074820788745403`*^9},ExpressionUUID->"ee043ea3-ae5f-4dea-8a2d-\
e5f82bc82b18"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic use for linear axes", "Subsubsection",ExpressionUUID->"facd6d9a-fbbf-4645-b334-6101f29e104b"],

Cell[TextData[{
 "\t The default tick marks produced by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s plotting functions are typically not ideal for publication.  It is often \
desirable to be able to change the tick spacing from that selected by ",
 StyleBox["Mathematica.",
  FontSlant->"Italic"],
 "  The tick marks are also often too short to be easily visible."
}], "Text",
 CellChangeTimes->{{3.51613436621875*^9, 3.5161343939375*^9}, {
  3.516134432953125*^9, 
  3.51613459659375*^9}},ExpressionUUID->"12e832d3-63b0-4427-b963-\
7bf03a4ba156"],

Cell[TextData[{
 "\tIt is possible to override the default ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " ticks by specifying a list of tick marks, complete with formatting \
information, as the value for the ",
 StyleBox["Ticks",
  FontFamily->"Courier New"],
 " or ",
 StyleBox["FrameTicks",
  FontFamily->"Courier New"],
 " option (see the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " documentation for basic plotting options).  It is prohibitively tedious to \
construct such lists by hand.  The CustomTicks package provides functions to \
automatically construct lists of tick marks, with detailed control over \
formatting."
}], "Text",ExpressionUUID->"fc97c809-0d00-4e2a-b890-a5b8ddc05d0a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<SymbolSummary\>\"", ",", "\[IndentingNewLine]", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<LinTicks[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x1\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x2\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Produces linear tick specifications, with automatically chosen \
major and minor tick intervals\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<LinTicks[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x1\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x2\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<interval\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<subdivs\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Produces linear tick specifications, with manually chosen major \
and minor tick intervals\>\"", "}"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{"{", "\"\<Tick specification function.\>\"", "}"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<OptionSummaryWideDescription\>\"", ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickRange\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<{-Infinity,Infinity}\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Limits the drawing of ticks (and their labels) to given \
coordinate range\>\"", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<ShowMinorTicks\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<True\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Controls whether or not the minor ticks are drawn; mainly for use \
with \>\"", ",", " ", 
      RowBox[{"texttt", "[", "\"\<LogTicks\>\"", "]"}], ",", 
      "\"\< (see below)\>\""}], "}"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{
   "{", "\"\<Options controlling the coordinates at which tick marks are \
displayed.\>\"", "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{"\"\<OptionSummaryWideDescription\>\"", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<ShowTickLabels\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<True\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Controls whether or not major tick labels are printed\>\"", 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<ShowMinorTickLabels\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<True\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Controls whether or not minor tick labels are printed\>\"", 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickLabelRange\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<{-Infinity,Infinity}\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Limits printing of major tick labels to given coordinate \
range\>\"", "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<ShowFirst\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<True\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Controls whether or not first major tick label is printed\>\"", 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<ShowLast\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<True\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Controls whether or not last major tick label is printed\>\"", 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickLabelStep\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<1\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Limits printing of major tick labels to one in every \>\"", ",", 
      " ", 
      RowBox[{"texttt", "[", "\"\<TickLabelStep\>\"", "]"}], ",", 
      "\"\< major ticks\>\""}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickLabelStart\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<0\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Used in conjunction with \>\"", ",", " ", 
      RowBox[{"texttt", "[", "\"\<TickLabelStep\>\"", "]"}], ",", 
      "\"\< chooses which subset of major tick labels are printed\>\""}], 
     "}"}]}], "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MakeCaptionBox", "[", 
    RowBox[{
    "{", "\"\<Options controlling which tick marks are accompanied by labels.\
\>\"", "}"}], "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{"\"\<OptionSummaryWideDescription\>\"", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<MajorTickLength\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<0.01\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Length for the major ticks (may also be given as a list of two \
lengths, into and out of the frame, as described in the Mathematica \
documentation for \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<Ticks\>\"", "]"}], ",", "\"\<)\>\""}], 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<MinorTickLength\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<0.005\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Length for the minor ticks (may also be given as a list of two \
lengths, into and out of the frame, as described in the Mathematica \
documentation for \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<Ticks\>\"", "]"}], ",", "\"\<)\>\""}], 
     "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickDirection\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<In\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Orientation of tick marks (\>\"", ",", 
      RowBox[{"texttt", "[", "\"\<In\>\"", "]"}], ",", 
      "\"\< for tick marks into the frame, \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<Out\>\"", "]"}], ",", 
      "\"\<for tick marks out of the frame, or \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<All\>\"", "]"}], ",", 
      "\"\<for tick marks both into and out of the frame)\>\""}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickLengthScale\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<1\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Additional scale factor by which to lengthen both the major and \
minor ticks, relative to the lengths given by the options \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<MajorTickLength\>\"", "]"}], ",", 
      "\"\< and \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<MinorTickLength\>\"", "]"}], ",", 
      "\"\< above\>\""}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<MajorTickStyle\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<{}\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<List specifying the line style for the major ticks\>\"", "}"}], 
    ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<MinorTickStyle\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<{}\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<List specifying the line style for the minor ticks\>\"", 
     "}"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"MakeCaptionBox", "[", 
    RowBox[{
    "{", "\"\<Options specifying the appearance of tick marks.\>\"", "}"}], 
    "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<OptionSummaryWideDescription\>\"", ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<DecimalDigits\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<Automatic\>\"", "]"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Sets number of digits after decimal place for major tick labels; if \
\>\"", ",", 
      RowBox[{"texttt", "[", "\"\<Automatic\>\"", "]"}], ",", 
      "\"\<, the maximum number of digits needed for any label is used for \
all labels\>\""}], "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<NumberSigns\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<Automatic\>\"", "]"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Strings to use as signs for negative and positive numbers; see \
\>\"", ",", 
      RowBox[{"textit", "[", "\"\<Mathematica\>\"", "]"}], ",", 
      "\"\<documentation and discussion of \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<FixedPointForm\>\"", "]"}], ",", 
      "\"\< function below\>\""}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<NumberPoint\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<\\\".\\\"\>\"", "]"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", "\"\<String to use as decimal point\>\"", "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}],
   ";"}], "\n", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{
   "{", "\"\<Options specifying the numerical formatting of tick labels (if \
the default labeling function is used).\>\"", "}"}], "]"}], ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBmIQzdAwSVnW7ZUjQ8NebTDNwGcA4W+E0AwLrCD09UAI
/S0PIj+xDEJ37IWIP7wC4e+8AeEbPoLwhZ9D6Ol/IOKpbHJg+qgMhE5WAtMN
jRCa4eUFCF1xGUS7xJ9Q6Xz7ynFZ5gRNEK1h9FMPRLvftLUF0XHB81xA9Pcl
XAEgek5xSiiIdjnzJwxEP7G6EAWiy7KLE0B0w5WeVBDdavs3DUS/nXbDrhtI
71itbg+i8w0iXt4NfO24yrbgFYhuM3nAcw9If/Z3EwDRACJYirI=
  "],
 Hyphenation->False,
 CellLabel->"In[4]:=",ExpressionUUID->"cfeddf36-ba9b-4a0f-94ce-aa8e5ff19a9b"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       RowBox[{
        StyleBox[
         RowBox[{"LinTicks", "["}],
         FontFamily->"Courier"], 
        StyleBox["x1",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["x2",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Produces", " ", "linear", " ", "tick", " ", "specifications"}], ",", 
        " ", 
        RowBox[{
        "with", " ", "automatically", " ", "chosen", " ", "major", " ", "and",
          " ", "minor", " ", "tick", " ", "intervals"}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"LinTicks", "["}],
         FontFamily->"Courier"], 
        StyleBox["x1",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["x2",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["interval",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["subdivs",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Produces", " ", "linear", " ", "tick", " ", "specifications"}], ",", 
        " ", 
        RowBox[{
        "with", " ", "manually", " ", "chosen", " ", "major", " ", "and", " ",
          "minor", " ", "tick", " ", "intervals"}]}]}
     }]], "2ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{"Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
   GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.31], {
        Scaled[0.65]}}, "Rows" -> {{1.}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.807481409525551*^9},ExpressionUUID->"863de696-12ba-4143-a4c8-\
056f565b429d"],

Cell["Tick specification function.", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.8074814095469*^9},ExpressionUUID->"166851b1-0c63-4796-8168-f88b9e059239"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       StyleBox[
        RowBox[{"option", " ", "name"}], "SO10"], 
       StyleBox[
        RowBox[{"default", " ", "value"}], "SO10"], ""},
      {
       StyleBox["TickRange",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}],
        FontFamily->"Courier"], 
       RowBox[{
       "Limits", " ", "the", " ", "drawing", " ", "of", " ", "ticks", " ", 
        RowBox[{"(", 
         RowBox[{"and", " ", "their", " ", "labels"}], ")"}], " ", "to", " ", 
        "given", " ", "coordinate", " ", "range"}]},
      {
       StyleBox["ShowMinorTicks",
        FontFamily->"Courier"], 
       StyleBox["True",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
         RowBox[{
         "Controls", " ", "whether", " ", "or", " ", "not", " ", "the", " ", 
          "minor", " ", "ticks", " ", "are", " ", "drawn"}], ";", " ", 
         RowBox[{"mainly", " ", "for", " ", "use", " ", "with", " "}]}], 
        StyleBox["LogTicks",
         FontFamily->"Courier"], 
        RowBox[{" ", 
         RowBox[{"(", 
          RowBox[{"see", " ", "below"}], ")"}]}]}]}
     }]], "3ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "Rows" -> {False, True, {False}, False}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.23], 
       Scaled[0.23], {
        Scaled[0.5]}}, "Rows" -> {{1.}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.807481409571844*^9},ExpressionUUID->"84997450-1f63-4ca2-bf6c-\
59a1d8190f6a"],

Cell["\<\
Options controlling the coordinates at which tick marks are displayed.\
\>", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.807481409596706*^9},ExpressionUUID->"e03a5cec-7b0f-4286-bfad-\
2d1c85bc4552"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       StyleBox[
        RowBox[{"option", " ", "name"}], "SO10"], 
       StyleBox[
        RowBox[{"default", " ", "value"}], "SO10"], ""},
      {
       StyleBox["ShowTickLabels",
        FontFamily->"Courier"], 
       StyleBox["True",
        FontFamily->"Courier"], 
       RowBox[{
       "Controls", " ", "whether", " ", "or", " ", "not", " ", "major", " ", 
        "tick", " ", "labels", " ", "are", " ", "printed"}]},
      {
       StyleBox["ShowMinorTickLabels",
        FontFamily->"Courier"], 
       StyleBox["True",
        FontFamily->"Courier"], 
       RowBox[{
       "Controls", " ", "whether", " ", "or", " ", "not", " ", "minor", " ", 
        "tick", " ", "labels", " ", "are", " ", "printed"}]},
      {
       StyleBox["TickLabelRange",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}],
        FontFamily->"Courier"], 
       RowBox[{
       "Limits", " ", "printing", " ", "of", " ", "major", " ", "tick", " ", 
        "labels", " ", "to", " ", "given", " ", "coordinate", " ", "range"}]},
      {
       StyleBox["ShowFirst",
        FontFamily->"Courier"], 
       StyleBox["True",
        FontFamily->"Courier"], 
       RowBox[{
       "Controls", " ", "whether", " ", "or", " ", "not", " ", "first", " ", 
        "major", " ", "tick", " ", "label", " ", "is", " ", "printed"}]},
      {
       StyleBox["ShowLast",
        FontFamily->"Courier"], 
       StyleBox["True",
        FontFamily->"Courier"], 
       RowBox[{
       "Controls", " ", "whether", " ", "or", " ", "not", " ", "last", " ", 
        "major", " ", "tick", " ", "label", " ", "is", " ", "printed"}]},
      {
       StyleBox["TickLabelStep",
        FontFamily->"Courier"], 
       StyleBox["1",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Limits", " ", "printing", " ", "of", " ", "major", " ", "tick", " ", 
         "labels", " ", "to", " ", "one", " ", "in", " ", "every", " "}], 
        StyleBox["TickLabelStep",
         FontFamily->"Courier"], 
        RowBox[{" ", 
         RowBox[{"major", " ", "ticks"}]}]}]},
      {
       StyleBox["TickLabelStart",
        FontFamily->"Courier"], 
       StyleBox["0",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{"Used", " ", "in", " ", "conjunction", " ", "with", " "}], 
        StyleBox["TickLabelStep",
         FontFamily->"Courier"], 
        RowBox[{" ", 
         RowBox[{
         "chooses", " ", "which", " ", "subset", " ", "of", " ", "major", " ",
           "tick", " ", "labels", " ", "are", " ", "printed"}]}]}]}
     }]], "3ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "Rows" -> {False, True, {False}, False}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.23], 
       Scaled[0.23], {
        Scaled[0.5]}}, "Rows" -> {{1.}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.8074814096151657`*^9},ExpressionUUID->"02573b4c-b83e-4c31-aa60-\
05f7fcdf7ff9"],

Cell["\<\
Options controlling which tick marks are accompanied by labels.\
\>", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.8074814096315002`*^9},ExpressionUUID->"3ef897e2-7e55-4581-865a-\
9bfd4ace3b28"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       StyleBox[
        RowBox[{"option", " ", "name"}], "SO10"], 
       StyleBox[
        RowBox[{"default", " ", "value"}], "SO10"], ""},
      {
       StyleBox["MajorTickLength",
        FontFamily->"Courier"], 
       StyleBox["0.01",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Length", " ", "for", " ", "the", " ", "major", " ", "ticks", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
           "may", " ", "also", " ", "be", " ", "given", " ", "as", " ", "a", 
            " ", "list", " ", "of", " ", "two", " ", "lengths"}], ",", " ", 
           RowBox[{
           "into", " ", "and", " ", "out", " ", "of", " ", "the", " ", 
            "frame"}], ",", " ", 
           RowBox[{
           "as", " ", "described", " ", "in", " ", "the", " ", "Mathematica", 
            " ", "documentation", " ", "for", " "}]}]}]}], 
        StyleBox["Ticks",
         FontFamily->"Courier"], ")"}]},
      {
       StyleBox["MinorTickLength",
        FontFamily->"Courier"], 
       StyleBox["0.005",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Length", " ", "for", " ", "the", " ", "minor", " ", "ticks", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
           "may", " ", "also", " ", "be", " ", "given", " ", "as", " ", "a", 
            " ", "list", " ", "of", " ", "two", " ", "lengths"}], ",", " ", 
           RowBox[{
           "into", " ", "and", " ", "out", " ", "of", " ", "the", " ", 
            "frame"}], ",", " ", 
           RowBox[{
           "as", " ", "described", " ", "in", " ", "the", " ", "Mathematica", 
            " ", "documentation", " ", "for", " "}]}]}]}], 
        StyleBox["Ticks",
         FontFamily->"Courier"], ")"}]},
      {
       StyleBox["TickDirection",
        FontFamily->"Courier"], 
       StyleBox["In",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Orientation", " ", "of", " ", "tick", " ", "marks", " ", "("}], 
        StyleBox["In",
         FontFamily->"Courier"], 
        RowBox[{" ", 
         RowBox[{
          RowBox[{
          "for", " ", "tick", " ", "marks", " ", "into", " ", "the", " ", 
           "frame"}], ",", " "}]}], 
        StyleBox["Out",
         FontFamily->"Courier"], 
        RowBox[{
         RowBox[{
         "for", " ", "tick", " ", "marks", " ", "out", " ", "of", " ", "the", 
          " ", "frame"}], ",", " ", "or", " "}], 
        StyleBox["All",
         FontFamily->"Courier"], 
        RowBox[{
         RowBox[{
         "for", " ", "tick", " ", "marks", " ", "both", " ", "into", " ", 
          "and", " ", "out", " ", "of", " ", "the", " ", "frame"}], ")"}]}]},
      {
       StyleBox["TickLengthScale",
        FontFamily->"Courier"], 
       StyleBox["1",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
         RowBox[{
         "Additional", " ", "scale", " ", "factor", " ", "by", " ", "which", 
          " ", "to", " ", "lengthen", " ", "both", " ", "the", " ", "major", 
          " ", "and", " ", "minor", " ", "ticks"}], ",", " ", 
         RowBox[{
         "relative", " ", "to", " ", "the", " ", "lengths", " ", "given", " ",
           "by", " ", "the", " ", "options", " "}]}], 
        StyleBox["MajorTickLength",
         FontFamily->"Courier"], 
        RowBox[{" ", "and", " "}], 
        StyleBox["MinorTickLength",
         FontFamily->"Courier"], 
        RowBox[{" ", "above"}]}]},
      {
       StyleBox["MajorTickStyle",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"{", "}"}],
        FontFamily->"Courier"], 
       RowBox[{
       "List", " ", "specifying", " ", "the", " ", "line", " ", "style", " ", 
        "for", " ", "the", " ", "major", " ", "ticks"}]},
      {
       StyleBox["MinorTickStyle",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"{", "}"}],
        FontFamily->"Courier"], 
       RowBox[{
       "List", " ", "specifying", " ", "the", " ", "line", " ", "style", " ", 
        "for", " ", "the", " ", "minor", " ", "ticks"}]}
     }]], "3ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "Rows" -> {False, True, {False}, False}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.23], 
       Scaled[0.23], {
        Scaled[0.5]}}, "Rows" -> {{1.}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.807481409648513*^9},ExpressionUUID->"1abbb6c7-97c5-42f5-b56b-\
e91893e0b104"],

Cell["Options specifying the appearance of tick marks.", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.8074814096696463`*^9},ExpressionUUID->"c4f895f2-cc73-4efd-8e78-\
85d98f2c07a0"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       StyleBox[
        RowBox[{"option", " ", "name"}], "SO10"], 
       StyleBox[
        RowBox[{"default", " ", "value"}], "SO10"], ""},
      {
       StyleBox["DecimalDigits",
        FontFamily->"Courier"], 
       StyleBox["Automatic",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
         RowBox[{
         "Sets", " ", "number", " ", "of", " ", "digits", " ", "after", " ", 
          "decimal", " ", "place", " ", "for", " ", "major", " ", "tick", " ",
           "labels"}], ";", " ", "if", " "}], 
        StyleBox["Automatic",
         FontFamily->"Courier"], 
        RowBox[{",", " ", 
         RowBox[{
         "the", " ", "maximum", " ", "number", " ", "of", " ", "digits", " ", 
          "needed", " ", "for", " ", "any", " ", "label", " ", "is", " ", 
          "used", " ", "for", " ", "all", " ", "labels"}]}]}]},
      {
       StyleBox["NumberSigns",
        FontFamily->"Courier"], 
       StyleBox["Automatic",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
         RowBox[{
         "Strings", " ", "to", " ", "use", " ", "as", " ", "signs", " ", 
          "for", " ", "negative", " ", "and", " ", "positive", " ", 
          "numbers"}], ";", " ", "see", " "}], 
        StyleBox["Mathematica",
         FontSlant->"Italic"], 
        RowBox[{
        "documentation", " ", "and", " ", "discussion", " ", "of", " "}], 
        StyleBox["FixedPointForm",
         FontFamily->"Courier"], 
        RowBox[{" ", 
         RowBox[{"function", " ", "below"}]}]}]},
      {
       StyleBox["NumberPoint",
        FontFamily->"Courier"], 
       StyleBox["\<\".\"\>",
        FontFamily->"Courier"], 
       RowBox[{
       "String", " ", "to", " ", "use", " ", "as", " ", "decimal", " ", 
        "point"}]}
     }]], "3ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "Rows" -> {False, True, {False}, False}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.23], 
       Scaled[0.23], {
        Scaled[0.5]}}, "Rows" -> {{1.}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.8074814096887503`*^9},ExpressionUUID->"82773f31-ae87-48b4-84a1-\
87157e24525b"],

Cell["\<\
Options specifying the numerical formatting of tick labels (if the default \
labeling function is used).\
\>", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.807481409696046*^9},ExpressionUUID->"b5b8fed1-06bd-4f72-8149-\
c744f7dcf43e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Logarithmic axes", "Subsubsection",ExpressionUUID->"2392c945-8773-4315-aea5-9a4ce94214b5"],

Cell[TextData[{
 "\tThe function ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " generates tick marks for logarithmic axes.  ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " can produce tick marks for an arbitrary logarithmic base (10 is the \
default, but ",
 StyleBox["e",
  FontSlant->"Italic"],
 " and 2 are other commonly useful bases).  Unlike the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " function, which produces cumbersome decimal labels (",
 StyleBox["e.g.",
  FontSlant->"Italic"],
 ", \"0.0000001\", \"0.000001\", \[Ellipsis]), ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " produces true exponential labels (",
 StyleBox["e.g.",
  FontSlant->"Italic"],
 ", \"",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "7"}]], TraditionalForm]],ExpressionUUID->
  "386ae6e1-cba3-4354-937d-0cb14306a1e5"],
 "\", \"",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "6"}]], TraditionalForm]],ExpressionUUID->
  "5d7a30be-ce3d-4809-9cd3-46dae4405691"],
 "\", \[Ellipsis])."
}], "Text",ExpressionUUID->"7d5661fa-261e-4ff0-b070-9bbb831aafae"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<SymbolSummary\>\"", ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<LogTicks[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<n1\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<n2\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Produces logarithmic tick specifications, base 10\>\"", "}"}], 
    ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<LogTicks[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<base\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<n1\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<n2\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Produces logarithmic tick specifications, arbitrary \>\"", ",", 
      RowBox[{"textit", "[", "\"\<base\>\"", "]"}]}], "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MakeCaptionBox", "[", 
    RowBox[{"{", "\"\<Logarithmic tick specification function.\>\"", "}"}], 
    "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellOpen->False,
 Hyphenation->False,
 CellLabel->"In[73]:=",ExpressionUUID->"823756dc-8f23-4fc4-a6d9-3573edf11c59"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       RowBox[{
        StyleBox[
         RowBox[{"LogTicks", "["}],
         FontFamily->"Courier"], 
        StyleBox["n1",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["n2",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Produces", " ", "logarithmic", " ", "tick", " ", "specifications"}], 
        ",", " ", 
        RowBox[{"base", " ", "10"}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"LogTicks", "["}],
         FontFamily->"Courier"], 
        StyleBox["base",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["n1",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["n2",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Produces", " ", "logarithmic", " ", "tick", " ", "specifications"}], 
        ",", " ", 
        RowBox[{"arbitrary", " ", 
         StyleBox["base",
          FontSlant->"Italic"]}]}]}
     }]], "2ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.31], {
        Scaled[0.65]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->
  True,ExpressionUUID->"57149e5f-6044-4cae-8860-b6b4be377020"],

Cell["Logarithmic tick specification function.", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->
  True,ExpressionUUID->"9e18ec93-3d34-4aed-938b-1c009c7fa01e"],

Cell[TextData[{
 "\t",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " must be given the starting power, ending power, and, optionally, the \
logarithmic base ",
 StyleBox["b",
  FontSlant->"Italic"],
 ".  For base 10, a total of eight minor ticks are produced in each major \
interval, at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Cross]", 
    SuperscriptBox["10", "n"]}], TraditionalForm]],ExpressionUUID->
  "c7d1d7f5-d1f9-42d9-b513-8f2693d5f99f"],
 " through ",
 Cell[BoxData[
  FormBox[
   RowBox[{"9", "\[Cross]", 
    SuperscriptBox["10", "n"]}], TraditionalForm]],ExpressionUUID->
  "99c12e16-00b7-4f1a-a3fe-669d836707b9"],
 ".  For an arbitrary base ",
 StyleBox["b",
  FontSlant->"Italic"],
 ", \[LeftCeiling]",
 StyleBox["b",
  FontSlant->"Italic"],
 "\[RightCeiling]-2 minor ticks are produced, at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Cross]", 
    SuperscriptBox["b", "n"]}], TraditionalForm]],ExpressionUUID->
  "9a6e4771-6ca1-4cdc-a161-8bcd5f1838fb"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3", "\[Cross]", 
    SuperscriptBox["b", "n"]}], TraditionalForm]],ExpressionUUID->
  "059e61a9-83af-444d-9a9d-85d6cde1a088"],
 ", \[Ellipsis].  Display of the minor ticks may be suppressed by specifying \
the option ",
 StyleBox["ShowMinorTicks\[Rule]False",
  FontFamily->"Courier New"],
 ".  Some ",
 "examples are shown below."
}], "Text",ExpressionUUID->"27c3f5a0-4c92-4ffa-92b3-ba4ebdc31235"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Scheme", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"CodeOpts", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Courier\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"SetOptions", "[", 
      RowBox[{"ManualLabel", ",", 
       RowBox[{"Offset", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"+", "1"}]}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"SetOrigin", "[", "1", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"SchemeAxis", "[", 
      RowBox[{"Left", ",", "0", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "2.3"}], "}"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"LogTicks", "[", 
         RowBox[{"0", ",", "2"}], "]"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.3"}]}], "}"}], ",", 
       RowBox[{"StackText", "[", 
        RowBox[{"Center", ",", "0.5", ",", 
         RowBox[{"{", "\"\<Base 10\>\"", "}"}]}], "]"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.8"}]}], "}"}], ",", "\"\<LogTicks[0,2]\>\"", ",", 
       "CodeOpts"}], "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"SetOrigin", "[", "2.2", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"SchemeAxis", "[", 
      RowBox[{"Left", ",", "0", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "2.3"}], "}"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"LogTicks", "[", 
         RowBox[{
          RowBox[{"-", "8"}], ",", "8", ",", 
          RowBox[{"TickLabelStep", "\[Rule]", "4"}], ",", 
          RowBox[{"TickPostTransformation", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"#", "/", "8"}], "+", "1"}], ")"}], "&"}], ")"}]}]}], 
         "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.3"}]}], "}"}], ",", 
       RowBox[{"StackText", "[", 
        RowBox[{"Center", ",", "0.5", ",", 
         RowBox[{"{", "\"\<Skipped labels\>\"", "}"}]}], "]"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.8"}]}], "}"}], ",", 
       RowBox[{"StackText", "[", 
        RowBox[{"Center", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
          "\"\<LogTicks[-8,8,\>\"", ",", "\"\<TickLabelStep\[Rule]4]\>\""}], 
          "}"}]}], "]"}], ",", "CodeOpts"}], "]"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"SetOrigin", "[", "3.5", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"SchemeAxis", "[", 
      RowBox[{"Left", ",", "0", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "2.3"}], "}"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"LogTicks", "[", 
         RowBox[{
          RowBox[{"-", "8"}], ",", "8", ",", 
          RowBox[{"ShowMinorTicks", "\[Rule]", "False"}], ",", 
          RowBox[{"TickLabelStep", "\[Rule]", "4"}], ",", 
          RowBox[{"TickPostTransformation", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"#", "/", "8"}], "+", "1"}], ")"}], "&"}], ")"}]}]}], 
         "]"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.3"}]}], "}"}], ",", 
       RowBox[{"StackText", "[", 
        RowBox[{"Center", ",", "0.5", ",", 
         RowBox[{"{", "\"\<No minor ticks\>\"", "}"}]}], "]"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.8"}]}], "}"}], ",", 
       RowBox[{"StackText", "[", 
        RowBox[{"Center", ",", "0", ",", 
         RowBox[{"{", 
          RowBox[{
          "\"\<LogTicks[-8,8,\>\"", ",", 
           "\"\<ShowMinorTicks\[Rule]False,\>\"", ",", 
           "\"\<TickLabelStep\[Rule]4]\>\""}], "}"}]}], "]"}], ",", 
       "CodeOpts"}], "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]",
      "\[IndentingNewLine]", 
     RowBox[{"SetOrigin", "[", "4.8", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"SchemeAxis", "[", 
      RowBox[{"Left", ",", "0", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "2.3"}], "}"}], ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"LogTicks", "[", 
         RowBox[{"E", ",", "0", ",", "4", ",", 
          RowBox[{"TickPostTransformation", "\[Rule]", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"#", "/", "2"}], ")"}], "&"}], ")"}]}]}], "]"}]}]}], 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.3"}]}], "}"}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<Base \>\"", ",", 
          RowBox[{"textit", "[", "\"\<e\>\"", "]"}]}], "}"}], "]"}]}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.8"}]}], "}"}], ",", "\"\<LogTicks[E,0,4]\>\"", ",", 
       "CodeOpts"}], "]"}], ","}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.5", ",", "5.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"72", "*", 
     RowBox[{"{", 
      RowBox[{"6.5", ",", "3.5"}], "}"}]}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.526233101546875*^9, 3.52623312053125*^9}, {
  3.52623315465625*^9, 3.5262331549375*^9}, {3.5262332785625*^9, 
  3.526233283859375*^9}, {3.526421732328125*^9, 3.52642174503125*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"49ccdae9-77f9-43e8-b0bd-1dc158eda0cc"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{0.9999999999999998, 0.}, {0.9999999999999998, 2.3}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{0.9679423076923075, 2.204742857142857}, {
     0.9999999999999998, 2.3}, {1.032057692307692, 2.204742857142857}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{1.0384692307692305`, 0.}, {0.9999999999999998, 0.}}], 
    LineBox[{{1.0384692307692305`, 1.}, {0.9999999999999998, 1.}}], 
    LineBox[{{1.0384692307692305`, 2.}, {0.9999999999999998, 2.}}], 
    LineBox[{{1.0192346153846152`, 0.30102999566398114`}, {0.9999999999999998,
      0.30102999566398114`}}], 
    LineBox[{{1.0192346153846152`, 0.4771212547196624}, {0.9999999999999998, 
     0.4771212547196624}}], 
    LineBox[{{1.0192346153846152`, 0.6020599913279623}, {0.9999999999999998, 
     0.6020599913279623}}], 
    LineBox[{{1.0192346153846152`, 0.6989700043360186}, {0.9999999999999998, 
     0.6989700043360186}}], 
    LineBox[{{1.0192346153846152`, 0.7781512503836435}, {0.9999999999999998, 
     0.7781512503836435}}], 
    LineBox[{{1.0192346153846152`, 0.8450980400142567}, {0.9999999999999998, 
     0.8450980400142567}}], 
    LineBox[{{1.0192346153846152`, 0.9030899869919433}, {0.9999999999999998, 
     0.9030899869919433}}], 
    LineBox[{{1.0192346153846152`, 0.9542425094393248}, {0.9999999999999998, 
     0.9542425094393248}}], 
    LineBox[{{1.0192346153846152`, 1.3010299956639813`}, {0.9999999999999998, 
     1.3010299956639813`}}], 
    LineBox[{{1.0192346153846152`, 1.4771212547196624`}, {0.9999999999999998, 
     1.4771212547196624`}}], 
    LineBox[{{1.0192346153846152`, 1.6020599913279623`}, {0.9999999999999998, 
     1.6020599913279623`}}], 
    LineBox[{{1.0192346153846152`, 1.6989700043360187`}, {0.9999999999999998, 
     1.6989700043360187`}}], 
    LineBox[{{1.0192346153846152`, 1.7781512503836434`}, {0.9999999999999998, 
     1.7781512503836434`}}], 
    LineBox[{{1.0192346153846152`, 1.8450980400142567`}, {0.9999999999999998, 
     1.8450980400142567`}}], 
    LineBox[{{1.0192346153846152`, 1.9030899869919433`}, {0.9999999999999998, 
     1.9030899869919433`}}], 
    LineBox[{{1.0192346153846152`, 1.9542425094393248`}, {0.9999999999999998, 
     1.9542425094393248`}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{2.1999999999999997`, 0.}, {2.1999999999999997`, 2.3}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{2.1679423076923072`, 2.204742857142857}, {
     2.1999999999999993`, 2.3}, {2.232057692307692, 2.204742857142857}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{2.2384692307692307`, 0.}, {2.1999999999999997`, 0.}}], 
    LineBox[{{2.2384692307692307`, 0.125}, {2.1999999999999997`, 0.125}}], 
    LineBox[{{2.2384692307692307`, 0.25}, {2.1999999999999997`, 0.25}}], 
    LineBox[{{2.2384692307692307`, 0.375}, {2.1999999999999997`, 0.375}}], 
    LineBox[{{2.2384692307692307`, 0.5}, {2.1999999999999997`, 0.5}}], 
    LineBox[{{2.2384692307692307`, 0.625}, {2.1999999999999997`, 0.625}}], 
    LineBox[{{2.2384692307692307`, 0.75}, {2.1999999999999997`, 0.75}}], 
    LineBox[{{2.2384692307692307`, 0.875}, {2.1999999999999997`, 0.875}}], 
    LineBox[{{2.2384692307692307`, 1.}, {2.1999999999999997`, 1.}}], 
    LineBox[{{2.2384692307692307`, 1.125}, {2.1999999999999997`, 1.125}}], 
    LineBox[{{2.2384692307692307`, 1.25}, {2.1999999999999997`, 1.25}}], 
    LineBox[{{2.2384692307692307`, 1.375}, {2.1999999999999997`, 1.375}}], 
    LineBox[{{2.2384692307692307`, 1.5}, {2.1999999999999997`, 1.5}}], 
    LineBox[{{2.2384692307692307`, 1.625}, {2.1999999999999997`, 1.625}}], 
    LineBox[{{2.2384692307692307`, 1.75}, {2.1999999999999997`, 1.75}}], 
    LineBox[{{2.2384692307692307`, 1.875}, {2.1999999999999997`, 1.875}}], 
    LineBox[{{2.2384692307692307`, 2.}, {2.1999999999999997`, 2.}}], 
    LineBox[{{2.219234615384615, 0.03762874945799766}, {2.1999999999999997`, 
     0.03762874945799766}}], 
    LineBox[{{2.219234615384615, 0.059640156839957825`}, {2.1999999999999997`,
      0.059640156839957825`}}], 
    LineBox[{{2.219234615384615, 0.07525749891599531}, {2.1999999999999997`, 
     0.07525749891599531}}], 
    LineBox[{{2.219234615384615, 0.08737125054200234}, {2.1999999999999997`, 
     0.08737125054200234}}], 
    LineBox[{{2.219234615384615, 0.09726890629795548}, {2.1999999999999997`, 
     0.09726890629795548}}], 
    LineBox[{{2.219234615384615, 0.10563725500178212`}, {2.1999999999999997`, 
     0.10563725500178212`}}], 
    LineBox[{{2.219234615384615, 0.11288624837399297`}, {2.1999999999999997`, 
     0.11288624837399297`}}], 
    LineBox[{{2.219234615384615, 0.11928031367991565`}, {2.1999999999999997`, 
     0.11928031367991565`}}], 
    LineBox[{{2.219234615384615, 0.16262874945799766`}, {2.1999999999999997`, 
     0.16262874945799766`}}], 
    LineBox[{{2.219234615384615, 0.18464015683995783`}, {2.1999999999999997`, 
     0.18464015683995783`}}], 
    LineBox[{{2.219234615384615, 0.2002574989159953}, {2.1999999999999997`, 
     0.2002574989159953}}], 
    LineBox[{{2.219234615384615, 0.21237125054200234`}, {2.1999999999999997`, 
     0.21237125054200234`}}], 
    LineBox[{{2.219234615384615, 0.22226890629795548`}, {2.1999999999999997`, 
     0.22226890629795548`}}], 
    LineBox[{{2.219234615384615, 0.23063725500178212`}, {2.1999999999999997`, 
     0.23063725500178212`}}], 
    LineBox[{{2.219234615384615, 0.23788624837399297`}, {2.1999999999999997`, 
     0.23788624837399297`}}], 
    LineBox[{{2.219234615384615, 0.24428031367991565`}, {2.1999999999999997`, 
     0.24428031367991565`}}], 
    LineBox[{{2.219234615384615, 0.28762874945799766`}, {2.1999999999999997`, 
     0.28762874945799766`}}], 
    LineBox[{{2.219234615384615, 0.3096401568399578}, {2.1999999999999997`, 
     0.3096401568399578}}], 
    LineBox[{{2.219234615384615, 0.3252574989159953}, {2.1999999999999997`, 
     0.3252574989159953}}], 
    LineBox[{{2.219234615384615, 0.33737125054200234`}, {2.1999999999999997`, 
     0.33737125054200234`}}], 
    LineBox[{{2.219234615384615, 0.3472689062979555}, {2.1999999999999997`, 
     0.3472689062979555}}], 
    LineBox[{{2.219234615384615, 0.3556372550017821}, {2.1999999999999997`, 
     0.3556372550017821}}], 
    LineBox[{{2.219234615384615, 0.36288624837399297`}, {2.1999999999999997`, 
     0.36288624837399297`}}], 
    LineBox[{{2.219234615384615, 0.36928031367991565`}, {2.1999999999999997`, 
     0.36928031367991565`}}], 
    LineBox[{{2.219234615384615, 0.41262874945799766`}, {2.1999999999999997`, 
     0.41262874945799766`}}], 
    LineBox[{{2.219234615384615, 0.4346401568399578}, {2.1999999999999997`, 
     0.4346401568399578}}], 
    LineBox[{{2.219234615384615, 0.4502574989159953}, {2.1999999999999997`, 
     0.4502574989159953}}], 
    LineBox[{{2.219234615384615, 0.46237125054200234`}, {2.1999999999999997`, 
     0.46237125054200234`}}], 
    LineBox[{{2.219234615384615, 0.4722689062979555}, {2.1999999999999997`, 
     0.4722689062979555}}], 
    LineBox[{{2.219234615384615, 0.4806372550017821}, {2.1999999999999997`, 
     0.4806372550017821}}], 
    LineBox[{{2.219234615384615, 0.48788624837399297`}, {2.1999999999999997`, 
     0.48788624837399297`}}], 
    LineBox[{{2.219234615384615, 0.49428031367991565`}, {2.1999999999999997`, 
     0.49428031367991565`}}], 
    LineBox[{{2.219234615384615, 0.5376287494579977}, {2.1999999999999997`, 
     0.5376287494579977}}], 
    LineBox[{{2.219234615384615, 0.5596401568399578}, {2.1999999999999997`, 
     0.5596401568399578}}], 
    LineBox[{{2.219234615384615, 0.5752574989159953}, {2.1999999999999997`, 
     0.5752574989159953}}], 
    LineBox[{{2.219234615384615, 0.5873712505420023}, {2.1999999999999997`, 
     0.5873712505420023}}], 
    LineBox[{{2.219234615384615, 0.5972689062979555}, {2.1999999999999997`, 
     0.5972689062979555}}], 
    LineBox[{{2.219234615384615, 0.6056372550017821}, {2.1999999999999997`, 
     0.6056372550017821}}], 
    LineBox[{{2.219234615384615, 0.612886248373993}, {2.1999999999999997`, 
     0.612886248373993}}], 
    LineBox[{{2.219234615384615, 0.6192803136799157}, {2.1999999999999997`, 
     0.6192803136799157}}], 
    LineBox[{{2.219234615384615, 0.6626287494579977}, {2.1999999999999997`, 
     0.6626287494579977}}], 
    LineBox[{{2.219234615384615, 0.6846401568399578}, {2.1999999999999997`, 
     0.6846401568399578}}], 
    LineBox[{{2.219234615384615, 0.7002574989159953}, {2.1999999999999997`, 
     0.7002574989159953}}], 
    LineBox[{{2.219234615384615, 0.7123712505420023}, {2.1999999999999997`, 
     0.7123712505420023}}], 
    LineBox[{{2.219234615384615, 0.7222689062979555}, {2.1999999999999997`, 
     0.7222689062979555}}], 
    LineBox[{{2.219234615384615, 0.7306372550017821}, {2.1999999999999997`, 
     0.7306372550017821}}], 
    LineBox[{{2.219234615384615, 0.737886248373993}, {2.1999999999999997`, 
     0.737886248373993}}], 
    LineBox[{{2.219234615384615, 0.7442803136799157}, {2.1999999999999997`, 
     0.7442803136799157}}], 
    LineBox[{{2.219234615384615, 0.7876287494579977}, {2.1999999999999997`, 
     0.7876287494579977}}], 
    LineBox[{{2.219234615384615, 0.8096401568399578}, {2.1999999999999997`, 
     0.8096401568399578}}], 
    LineBox[{{2.219234615384615, 0.8252574989159953}, {2.1999999999999997`, 
     0.8252574989159953}}], 
    LineBox[{{2.219234615384615, 0.8373712505420023}, {2.1999999999999997`, 
     0.8373712505420023}}], 
    LineBox[{{2.219234615384615, 0.8472689062979555}, {2.1999999999999997`, 
     0.8472689062979555}}], 
    LineBox[{{2.219234615384615, 0.8556372550017821}, {2.1999999999999997`, 
     0.8556372550017821}}], 
    LineBox[{{2.219234615384615, 0.862886248373993}, {2.1999999999999997`, 
     0.862886248373993}}], 
    LineBox[{{2.219234615384615, 0.8692803136799157}, {2.1999999999999997`, 
     0.8692803136799157}}], 
    LineBox[{{2.219234615384615, 0.9126287494579977}, {2.1999999999999997`, 
     0.9126287494579977}}], 
    LineBox[{{2.219234615384615, 0.9346401568399578}, {2.1999999999999997`, 
     0.9346401568399578}}], 
    LineBox[{{2.219234615384615, 0.9502574989159953}, {2.1999999999999997`, 
     0.9502574989159953}}], 
    LineBox[{{2.219234615384615, 0.9623712505420023}, {2.1999999999999997`, 
     0.9623712505420023}}], 
    LineBox[{{2.219234615384615, 0.9722689062979555}, {2.1999999999999997`, 
     0.9722689062979555}}], 
    LineBox[{{2.219234615384615, 0.9806372550017821}, {2.1999999999999997`, 
     0.9806372550017821}}], 
    LineBox[{{2.219234615384615, 0.987886248373993}, {2.1999999999999997`, 
     0.987886248373993}}], 
    LineBox[{{2.219234615384615, 0.9942803136799157}, {2.1999999999999997`, 
     0.9942803136799157}}], 
    LineBox[{{2.219234615384615, 1.0376287494579977`}, {2.1999999999999997`, 
     1.0376287494579977`}}], 
    LineBox[{{2.219234615384615, 1.0596401568399578`}, {2.1999999999999997`, 
     1.0596401568399578`}}], 
    LineBox[{{2.219234615384615, 1.0752574989159953`}, {2.1999999999999997`, 
     1.0752574989159953`}}], 
    LineBox[{{2.219234615384615, 1.0873712505420023`}, {2.1999999999999997`, 
     1.0873712505420023`}}], 
    LineBox[{{2.219234615384615, 1.0972689062979555`}, {2.1999999999999997`, 
     1.0972689062979555`}}], 
    LineBox[{{2.219234615384615, 1.1056372550017821`}, {2.1999999999999997`, 
     1.1056372550017821`}}], 
    LineBox[{{2.219234615384615, 1.112886248373993}, {2.1999999999999997`, 
     1.112886248373993}}], 
    LineBox[{{2.219234615384615, 1.1192803136799157`}, {2.1999999999999997`, 
     1.1192803136799157`}}], 
    LineBox[{{2.219234615384615, 1.1626287494579977`}, {2.1999999999999997`, 
     1.1626287494579977`}}], 
    LineBox[{{2.219234615384615, 1.1846401568399578`}, {2.1999999999999997`, 
     1.1846401568399578`}}], 
    LineBox[{{2.219234615384615, 1.2002574989159953`}, {2.1999999999999997`, 
     1.2002574989159953`}}], 
    LineBox[{{2.219234615384615, 1.2123712505420023`}, {2.1999999999999997`, 
     1.2123712505420023`}}], 
    LineBox[{{2.219234615384615, 1.2222689062979555`}, {2.1999999999999997`, 
     1.2222689062979555`}}], 
    LineBox[{{2.219234615384615, 1.2306372550017821`}, {2.1999999999999997`, 
     1.2306372550017821`}}], 
    LineBox[{{2.219234615384615, 1.237886248373993}, {2.1999999999999997`, 
     1.237886248373993}}], 
    LineBox[{{2.219234615384615, 1.2442803136799157`}, {2.1999999999999997`, 
     1.2442803136799157`}}], 
    LineBox[{{2.219234615384615, 1.2876287494579977`}, {2.1999999999999997`, 
     1.2876287494579977`}}], 
    LineBox[{{2.219234615384615, 1.3096401568399578`}, {2.1999999999999997`, 
     1.3096401568399578`}}], 
    LineBox[{{2.219234615384615, 1.3252574989159953`}, {2.1999999999999997`, 
     1.3252574989159953`}}], 
    LineBox[{{2.219234615384615, 1.3373712505420023`}, {2.1999999999999997`, 
     1.3373712505420023`}}], 
    LineBox[{{2.219234615384615, 1.3472689062979555`}, {2.1999999999999997`, 
     1.3472689062979555`}}], 
    LineBox[{{2.219234615384615, 1.3556372550017821`}, {2.1999999999999997`, 
     1.3556372550017821`}}], 
    LineBox[{{2.219234615384615, 1.362886248373993}, {2.1999999999999997`, 
     1.362886248373993}}], 
    LineBox[{{2.219234615384615, 1.3692803136799157`}, {2.1999999999999997`, 
     1.3692803136799157`}}], 
    LineBox[{{2.219234615384615, 1.4126287494579977`}, {2.1999999999999997`, 
     1.4126287494579977`}}], 
    LineBox[{{2.219234615384615, 1.4346401568399578`}, {2.1999999999999997`, 
     1.4346401568399578`}}], 
    LineBox[{{2.219234615384615, 1.4502574989159953`}, {2.1999999999999997`, 
     1.4502574989159953`}}], 
    LineBox[{{2.219234615384615, 1.4623712505420023`}, {2.1999999999999997`, 
     1.4623712505420023`}}], 
    LineBox[{{2.219234615384615, 1.4722689062979555`}, {2.1999999999999997`, 
     1.4722689062979555`}}], 
    LineBox[{{2.219234615384615, 1.4806372550017821`}, {2.1999999999999997`, 
     1.4806372550017821`}}], 
    LineBox[{{2.219234615384615, 1.487886248373993}, {2.1999999999999997`, 
     1.487886248373993}}], 
    LineBox[{{2.219234615384615, 1.4942803136799157`}, {2.1999999999999997`, 
     1.4942803136799157`}}], 
    LineBox[{{2.219234615384615, 1.5376287494579977`}, {2.1999999999999997`, 
     1.5376287494579977`}}], 
    LineBox[{{2.219234615384615, 1.5596401568399578`}, {2.1999999999999997`, 
     1.5596401568399578`}}], 
    LineBox[{{2.219234615384615, 1.5752574989159953`}, {2.1999999999999997`, 
     1.5752574989159953`}}], 
    LineBox[{{2.219234615384615, 1.5873712505420023`}, {2.1999999999999997`, 
     1.5873712505420023`}}], 
    LineBox[{{2.219234615384615, 1.5972689062979555`}, {2.1999999999999997`, 
     1.5972689062979555`}}], 
    LineBox[{{2.219234615384615, 1.6056372550017821`}, {2.1999999999999997`, 
     1.6056372550017821`}}], 
    LineBox[{{2.219234615384615, 1.612886248373993}, {2.1999999999999997`, 
     1.612886248373993}}], 
    LineBox[{{2.219234615384615, 1.6192803136799157`}, {2.1999999999999997`, 
     1.6192803136799157`}}], 
    LineBox[{{2.219234615384615, 1.6626287494579977`}, {2.1999999999999997`, 
     1.6626287494579977`}}], 
    LineBox[{{2.219234615384615, 1.6846401568399578`}, {2.1999999999999997`, 
     1.6846401568399578`}}], 
    LineBox[{{2.219234615384615, 1.7002574989159953`}, {2.1999999999999997`, 
     1.7002574989159953`}}], 
    LineBox[{{2.219234615384615, 1.7123712505420023`}, {2.1999999999999997`, 
     1.7123712505420023`}}], 
    LineBox[{{2.219234615384615, 1.7222689062979555`}, {2.1999999999999997`, 
     1.7222689062979555`}}], 
    LineBox[{{2.219234615384615, 1.7306372550017821`}, {2.1999999999999997`, 
     1.7306372550017821`}}], 
    LineBox[{{2.219234615384615, 1.737886248373993}, {2.1999999999999997`, 
     1.737886248373993}}], 
    LineBox[{{2.219234615384615, 1.7442803136799157`}, {2.1999999999999997`, 
     1.7442803136799157`}}], 
    LineBox[{{2.219234615384615, 1.7876287494579977`}, {2.1999999999999997`, 
     1.7876287494579977`}}], 
    LineBox[{{2.219234615384615, 1.8096401568399578`}, {2.1999999999999997`, 
     1.8096401568399578`}}], 
    LineBox[{{2.219234615384615, 1.8252574989159953`}, {2.1999999999999997`, 
     1.8252574989159953`}}], 
    LineBox[{{2.219234615384615, 1.8373712505420023`}, {2.1999999999999997`, 
     1.8373712505420023`}}], 
    LineBox[{{2.219234615384615, 1.8472689062979555`}, {2.1999999999999997`, 
     1.8472689062979555`}}], 
    LineBox[{{2.219234615384615, 1.8556372550017821`}, {2.1999999999999997`, 
     1.8556372550017821`}}], 
    LineBox[{{2.219234615384615, 1.862886248373993}, {2.1999999999999997`, 
     1.862886248373993}}], 
    LineBox[{{2.219234615384615, 1.8692803136799157`}, {2.1999999999999997`, 
     1.8692803136799157`}}], 
    LineBox[{{2.219234615384615, 1.9126287494579977`}, {2.1999999999999997`, 
     1.9126287494579977`}}], 
    LineBox[{{2.219234615384615, 1.9346401568399578`}, {2.1999999999999997`, 
     1.9346401568399578`}}], 
    LineBox[{{2.219234615384615, 1.9502574989159953`}, {2.1999999999999997`, 
     1.9502574989159953`}}], 
    LineBox[{{2.219234615384615, 1.9623712505420023`}, {2.1999999999999997`, 
     1.9623712505420023`}}], 
    LineBox[{{2.219234615384615, 1.9722689062979555`}, {2.1999999999999997`, 
     1.9722689062979555`}}], 
    LineBox[{{2.219234615384615, 1.9806372550017821`}, {2.1999999999999997`, 
     1.9806372550017821`}}], 
    LineBox[{{2.219234615384615, 1.987886248373993}, {2.1999999999999997`, 
     1.987886248373993}}], 
    LineBox[{{2.219234615384615, 1.9942803136799157`}, {2.1999999999999997`, 
     1.9942803136799157`}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{3.4999999999999996`, 0.}, {3.4999999999999996`, 2.3}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{3.467942307692307, 2.204742857142857}, {
     3.499999999999999, 2.3}, {3.5320576923076916`, 2.204742857142857}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{3.5384692307692305`, 0.}, {3.4999999999999996`, 0.}}], 
    LineBox[{{3.5384692307692305`, 0.125}, {3.4999999999999996`, 0.125}}], 
    LineBox[{{3.5384692307692305`, 0.25}, {3.4999999999999996`, 0.25}}], 
    LineBox[{{3.5384692307692305`, 0.375}, {3.4999999999999996`, 0.375}}], 
    LineBox[{{3.5384692307692305`, 0.5}, {3.4999999999999996`, 0.5}}], 
    LineBox[{{3.5384692307692305`, 0.625}, {3.4999999999999996`, 0.625}}], 
    LineBox[{{3.5384692307692305`, 0.75}, {3.4999999999999996`, 0.75}}], 
    LineBox[{{3.5384692307692305`, 0.875}, {3.4999999999999996`, 0.875}}], 
    LineBox[{{3.5384692307692305`, 1.}, {3.4999999999999996`, 1.}}], 
    LineBox[{{3.5384692307692305`, 1.125}, {3.4999999999999996`, 1.125}}], 
    LineBox[{{3.5384692307692305`, 1.25}, {3.4999999999999996`, 1.25}}], 
    LineBox[{{3.5384692307692305`, 1.375}, {3.4999999999999996`, 1.375}}], 
    LineBox[{{3.5384692307692305`, 1.5}, {3.4999999999999996`, 1.5}}], 
    LineBox[{{3.5384692307692305`, 1.625}, {3.4999999999999996`, 1.625}}], 
    LineBox[{{3.5384692307692305`, 1.75}, {3.4999999999999996`, 1.75}}], 
    LineBox[{{3.5384692307692305`, 1.875}, {3.4999999999999996`, 1.875}}], 
    LineBox[{{3.5384692307692305`, 2.}, {3.4999999999999996`, 2.}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{4.8, 0.}, {4.8, 2.3}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{4.767942307692308, 2.204742857142857}, {4.8, 2.3}, {
     4.832057692307692, 2.204742857142857}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], {LineBox[{{4.83846923076923, 0.}, {4.8, 0.}}], 
     LineBox[{{4.83846923076923, 0.5}, {4.8, 0.5}}], 
     LineBox[{{4.83846923076923, 1.}, {4.8, 1.}}], 
     LineBox[{{4.83846923076923, 1.5}, {4.8, 1.5}}], 
     LineBox[{{4.83846923076923, 2.}, {4.8, 2.}}], 
     LineBox[{{4.819234615384615, 0.34657359027997264`}, {4.8, 
      0.34657359027997264`}}], 
     LineBox[{{4.819234615384615, 0.8465735902799727}, {4.8, 
      0.8465735902799727}}], 
     LineBox[{{4.819234615384615, 1.3465735902799727`}, {4.8, 
      1.3465735902799727`}}], 
     LineBox[{{4.819234615384615, 1.8465735902799727`}, {4.8, 
      1.8465735902799727`}}]}, InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "0"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {0.9946570512820511, 0.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "1"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {0.9946570512820511, 1.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "2"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {0.9946570512820511, 2.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[GridBox[{
          {
           RowBox[{"Base", " ", "10"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{
              Offset[0.2]}}, "RowsIndexed" -> {}}],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {0.9999999999999998, -0.3}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"LogTicks[0,2]\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Courier",
       FontSize->10,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {0.9999999999999998, -0.8}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "8"}]],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.194657051282051, 0.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "4"}]],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.194657051282051, 0.5}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "0"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.194657051282051, 1.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "4"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.194657051282051, 1.5}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "8"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.194657051282051, 2.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[GridBox[{
          {
           RowBox[{"Skipped", " ", "labels"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{
              Offset[0.2]}}, "RowsIndexed" -> {}}],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.1999999999999997, -0.3}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[GridBox[{
          {
           RowBox[{"LogTicks", "[", 
            RowBox[{
             RowBox[{"-", "8"}], ",", "8", ","}]}]},
          {
           RowBox[{
            RowBox[{"TickLabelStep", "\[Rule]", "4"}], "]"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Courier",
       FontSize->10,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.1999999999999997, -0.8}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "8"}]],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3.4946570512820507, 0.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "4"}]],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3.4946570512820507, 0.5}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "0"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3.4946570512820507, 1.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "4"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3.4946570512820507, 1.5}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox["10", "8"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3.4946570512820507, 2.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[GridBox[{
          {
           RowBox[{"No", " ", "minor", " ", "ticks"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{
              Offset[0.2]}}, "RowsIndexed" -> {}}],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3.4999999999999996, -0.3}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[GridBox[{
          {
           RowBox[{"LogTicks", "[", 
            RowBox[{
             RowBox[{"-", "8"}], ",", "8", ","}]}]},
          {
           RowBox[{
            RowBox[{"ShowMinorTicks", "\[Rule]", "False"}], ","}]},
          {
           RowBox[{
            RowBox[{"TickLabelStep", "\[Rule]", "4"}], "]"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Courier",
       FontSize->10,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3.4999999999999996, -0.8}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox[
          StyleBox["\<\"e\"\>",
           StripOnInput->False,
           FontFamily->"Italic"], "0"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {4.794657051282051, 0.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox[
          StyleBox["\<\"e\"\>",
           StripOnInput->False,
           FontFamily->"Italic"], "1"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {4.794657051282051, 0.5}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox[
          StyleBox["\<\"e\"\>",
           StripOnInput->False,
           FontFamily->"Italic"], "2"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {4.794657051282051, 1.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox[
          StyleBox["\<\"e\"\>",
           StripOnInput->False,
           FontFamily->"Italic"], "3"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {4.794657051282051, 1.5}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        TagBox[
         SuperscriptBox[
          StyleBox["\<\"e\"\>",
           StripOnInput->False,
           FontFamily->"Italic"], "4"],
         DisplayForm],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {4.794657051282051, 2.}, {1, 0}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[
        RowBox[{"Base", " ", 
         TagBox[
          StyleBox["\<\"e\"\>",
           FontSlant->"Italic"],
          StyleForm[#, FontSlant -> "Italic"]& ]}],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {4.8, -0.3}, {0, 1}, Automatic, {1, 0}], InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"LogTicks[E,0,4]\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Courier",
       FontSize->10,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {4.8, -0.8}, {0, 1}, Automatic, {1, 0}]}},
  AspectRatio->0.5384615384615385,
  Axes->False,
  Background->None,
  BaseStyle->{
   FontFamily -> "Times", FontSize -> 12, FontSlant -> "Plain", FontTracking -> 
    "Plain", FontWeight -> "Plain", FontColor -> GrayLevel[0], FontOpacity -> 
    1, ShowAutoStyles -> False, SingleLetterItalics -> False},
  DisplayFunction->Identity,
  Frame->False,
  FrameLabel->{None, None, None, None},
  FrameStyle->Directive[{
     GrayLevel[0], 
     Opacity[1], 
     CapForm[None], 
     AbsoluteThickness[1], 
     AbsoluteDashing[{}]}],
  FrameTicks->None,
  ImageSize->{468., 252.},
  PlotRange->{{0.4995, 5.5005}, {-1.5004, 2.5004}},
  Ticks->None]], "Output",
 CellChangeTimes->{{3.526421714609375*^9, 3.526421746296875*^9}},
 CellLabel->"Out[13]=",ExpressionUUID->"c387d245-84fd-4fa0-a5c8-2b8c4ef916f8"]
}, Open  ]],

Cell[TextData[{
 "\tThis tick function was designed on the assumption that you will be \
generating your plots with ",
 StyleBox["logarithmic",
  FontSlant->"Italic"],
 " axes the \[OpenCurlyDoubleQuote]manual\[CloseCurlyDoubleQuote] way.  That \
is, as far as the plotting functions are concerned, you are actually \
generating ",
 StyleBox["linear",
  FontSlant->"Italic"],
 " plots, but you have taken the logarithm of either the ",
 StyleBox["x",
  FontSlant->"Italic"],
 "-axis or ",
 StyleBox["y",
  FontSlant->"Italic"],
 "-axis variable.  Specifically, for base 10,\n\t(1) a ",
 StyleBox["logarithmic",
  FontSlant->"Italic"],
 " (or ",
 StyleBox["linear",
  FontSlant->"Italic"],
 "-",
 StyleBox["log",
  FontSlant->"Italic"],
 ") plot of ",
 StyleBox["f",
  FontSlant->"Italic"],
 " is obtained by plotting ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["log", "10"], TraditionalForm]],ExpressionUUID->
  "f2e690cd-cfca-4382-848b-d58f839fe672"],
 " ",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["x",
  FontSlant->"Italic"],
 "), \n\t(2) a ",
 StyleBox["log",
  FontSlant->"Italic"],
 "-",
 StyleBox["linear",
  FontSlant->"Italic"],
 " plot of ",
 StyleBox["f",
  FontSlant->"Italic"],
 " is obtained by plotting ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    SuperscriptBox["10", 
     StyleBox["x",
      FontSlant->"Italic"]], ")"}], TraditionalForm]],ExpressionUUID->
  "33eeffc0-5cb4-4930-b939-b118e19f128e"],
 ", and\n\t(3) a ",
 StyleBox["log",
  FontSlant->"Italic"],
 "-",
 StyleBox["log",
  FontSlant->"Italic"],
 " plot of ",
 StyleBox["f",
  FontSlant->"Italic"],
 " is obtained by plotting ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["log", "10"], TraditionalForm]],ExpressionUUID->
  "c1aa5724-7b2b-44fa-9c44-e6a6d51a2405"],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"f", "(", 
    SuperscriptBox["10", 
     StyleBox["x",
      FontSlant->"Italic"]], ")"}], TraditionalForm]],ExpressionUUID->
  "aee5adf9-8c17-4280-9251-39bf713d3eaa"],
 "\non ordinary linear axes.  A similar procedure holds for bases other than \
10.  Examples of a logarithmic plot and a log-log plot follow."
}], "Text",
 CellChangeTimes->{{3.395151262703125*^9, 3.395151283046875*^9}, {
  3.6141987005863647`*^9, 3.614198723066004*^9}, {3.6141987891789203`*^9, 
  3.6141988224381785`*^9}},ExpressionUUID->"0448b59a-6af4-495a-9024-\
8129f44cd4a2"],

Cell["\<\
Plot[
    {Log10[Cosh[x]],Log10[Sinh[x]]},{x,0,10},
    PlotRange\[Rule]{{-0.0001,4},{-0.5,2.5}},
    FrameTicks\[Rule]{
        {LogTicks[10,-1,3],LogTicks[10,-1,3,ShowTickLabels\[Rule]False]},
        {LinTicks[0,4],LinTicks[0,4,ShowTickLabels\[Rule]False]}
        },
    Axes\[Rule]False,Frame\[Rule]True,ImageSize\[Rule]72*3
    ]\
\>", "Program",
 CellChangeTimes->{{3.3951510565625*^9, 3.395151062203125*^9}, 
   3.3951511525625*^9, 3.424727620046875*^9, 3.516134878828125*^9, {
   3.6142024957381134`*^9, 3.6142025125830765`*^9}, {3.807477894717758*^9, 
   3.807477953947959*^9}, {3.807478589470667*^9, 3.80747865232036*^9}},
 CellLabel->"In[96]:=",ExpressionUUID->"93852e88-1ba5-4dc8-aa7c-0e6cac73295b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Log10", "[", 
      RowBox[{"Cosh", "[", "x", "]"}], "]"}], ",", 
     RowBox[{"Log10", "[", 
      RowBox[{"Sinh", "[", "x", "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.0001"}], ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"LogTicks", "[", 
         RowBox[{"10", ",", 
          RowBox[{"-", "1"}], ",", "3"}], "]"}], ",", 
        RowBox[{"LogTicks", "[", 
         RowBox[{"10", ",", 
          RowBox[{"-", "1"}], ",", "3", ",", 
          RowBox[{"ShowTickLabels", "\[Rule]", "False"}]}], "]"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"LinTicks", "[", 
         RowBox[{"0", ",", "4"}], "]"}], ",", 
        RowBox[{"LinTicks", "[", 
         RowBox[{"0", ",", "4", ",", 
          RowBox[{"ShowTickLabels", "\[Rule]", "False"}]}], "]"}]}], "}"}]}], 
     "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"72", "*", "3"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.39515104653125*^9, 3.395151048890625*^9}, 
   3.4247276476875*^9, 3.51613487109375*^9, {3.6142026308908434`*^9, 
   3.6142026312908664`*^9}, 3.8074779941679*^9, {3.807478511004071*^9, 
   3.807478513666163*^9}, 3.807478660584138*^9},
 CellLabel->"In[29]:=",ExpressionUUID->"25e7dd5d-42f7-449b-b16d-5e955d9e1267"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwdkos31IkCx8ejWY8SY28eqRlzEmmOR81tazy+v7IoK4dia9XFyJg8Q14r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       "]]},
     Annotation[#, "Charting`Private`Tag$23250#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwBUQOu/CFib1JlAgAAADQAAAACAAAALc+Ru5zq0z8AAAAAAADgvyRnWLwY
OdQ/ssp//XKP37/KA4QuABPVP0xN73f7X96/Fj3bEs/G1j+QQhDIyCHcv66v
idtsLto/HpR9hbQS2L/qEuqMSmHaP7PYcQHr2de/J3ZKPiiU2j8eD4Qsg6HX
v6A8C6Hj+do/k3BVc9Ix17+SyYxmWsXbP4xQkdbDVta/duOP8Udc3T8p2u71
w7DUv58Ly4MRReA/mSg8HyGd0b8+PXtcgF7gP4LDCukebtG/3G4rNe934D85
0TI9Wj/RvxjSi+bMquA/+19IUYbi0L+RmExJiBDhPw3rhIyeK9C/gyXODv/b
4T+idIvvWpDNv2c/0ZnscuM/J3X3KqBMyL8Aova624vjPztt5Ory/Me/mAQc
3Mqk4z+KbV2rla3Hv8jJZh6p1uM/UzyrpMcPx78oVPyiZTrkPzKE43HF18W/
6GgnrN4B5T/OzmKBcnXDv2qSfb7QkOY/wtfF++nEvb9u5SnjtK7pP+PIEc4x
hqm/CiGEJ9848D+FQLLSzfezP44QyyqhYPM/67j8dJegxz9i21S/A8z2P9nT
5If6rdI/ccWEYm8n+j/btDuJKxfZP7FwDFMYSf0/C3Tam1ji3j+he2vqMFcA
QBDf5JKOhOI/gp/8UfTsAUDJ75VMTFnlPwDT4EC8egNAZOozXmYZ6D8mdGZ4
VCoFQGb9/WCbEOs/5PWXVgu9BkC5mPTtCtLtP0rlan2ScQhADdMB2Elm8D9O
5JArHh4KQK6Uq9ne2/E/6sNigMitC0DUtMoK2zfzPy4R1h1DXw1ACYB/Uvqw
9D8KP/Vh3PMOQBiddKDIEPY/R+1a9yJVEECnNSCb2o33P9jCZAFaLBFAAQSx
5eQD+T+1iMReIPURQPyOwJHIYPo/ZgV14M7OEkAZOHJPA9v7P2Nye7UMmhNA
Rct0riA8/T8vZyvOTGEUQEx9YfRKlv4/zxIsC3U5FUCtYv7d6AYAQLuugpss
AxZAk5NUPyC2AEB7ASpQzN0WQE5hC34GdAFACtx6SG60F0BavsbMdC4CQOWm
IZSffBhAHMKr5VfcAkCUKBkEuVUZQDxVlDnqmANAwleNNWfMGUAAAAAAAAAE
QPIen5o=
       "]]},
     Annotation[#, "Charting`Private`Tag$23250#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Times"},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{{{-1., 
       FormBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {0., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {1., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {2., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {3., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {-0.6989700043360189, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.5228787452803376, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.3979400086720377, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.30102999566398136`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.22184874961635648`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.1549019599857433, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.09691001300805668, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.04575749056067524, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      0.30102999566398114`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4771212547196624, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6020599913279623, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6989700043360186, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.7781512503836435, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8450980400142567, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9030899869919433, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9542425094393248, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.4771212547196624`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.6020599913279623`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.8450980400142567`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.4771212547196626`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.6020599913279625`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.845098040014257, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{-1., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {0., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {1., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {2., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {3., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {-0.6989700043360189, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.5228787452803376, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.3979400086720377, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.30102999566398136`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.22184874961635648`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.1549019599857433, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.09691001300805668, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.04575749056067524, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      0.30102999566398114`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4771212547196624, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6020599913279623, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6989700043360186, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.7781512503836435, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8450980400142567, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9030899869919433, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9542425094393248, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.4771212547196624`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.6020599913279623`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.8450980400142567`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.4771212547196626`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.6020599913279625`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.845098040014257, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}}, {{{0., 
       FormBox["\"0\"", TraditionalForm], {0.01, 0}, {}}, {1., 
       FormBox["\"1\"", TraditionalForm], {0.01, 0}, {}}, {2., 
       FormBox["\"2\"", TraditionalForm], {0.01, 0}, {}}, {3., 
       FormBox["\"3\"", TraditionalForm], {0.01, 0}, {}}, {4., 
       FormBox["\"4\"", TraditionalForm], {0.01, 0}, {}}, {0.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6000000000000001, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{0., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {1., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {2., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {3., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {4., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {0.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6000000000000001, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->216,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.0001, 4}, {-0.5, 2.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.526421771359375*^9, {3.614202626529594*^9, 3.6142026369541903`*^9}, 
   3.807477998582402*^9, 3.807478514294447*^9, 3.807478661370741*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"5798dee0-2756-4883-a39d-44b1b2406a15"]
}, Open  ]],

Cell["\<\
Plot[
    {Log10[(10^x)^2],Log10[(10^x)^5]},{x,-1,3},
    PlotRange\[Rule]{{-0.0001,3},{-0.5,4.5}},
    FrameTicks\[Rule]{
        {LogTicks[10,-1,5],None},
        {LogTicks[10,0,3],None}
        },
    Axes\[Rule]False,Frame\[Rule]True,ImageSize\[Rule]72*3
    ]\
\>", "Program",
 CellChangeTimes->{{3.395151130390625*^9, 3.395151149828125*^9}, {
   3.424727626546875*^9, 3.424727635984375*^9}, 3.516134882390625*^9, {
   3.6142025489981594`*^9, 3.614202549753203*^9}, {3.807477916742045*^9, 
   3.8074779320299473`*^9}, {3.807478057969111*^9, 3.807478059190268*^9}, {
   3.807478667368434*^9, 3.807478681175681*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"9b0b5418-90e0-48a9-8681-a1cb1eb5efe6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"10", "^", "x"}], ")"}], "^", "2"}]}], "]"}], ",", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"10", "^", "x"}], ")"}], "^", "5"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "1"}], ",", "3"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.0001"}], ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.5"}], ",", "4.5"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"LogTicks", "[", 
         RowBox[{"10", ",", 
          RowBox[{"-", "1"}], ",", "5"}], "]"}], ",", "None"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"LogTicks", "[", 
         RowBox[{"10", ",", "0", ",", "3"}], "]"}], ",", "None"}], "}"}]}], 
     "\[IndentingNewLine]", "}"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"72", "*", "3"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontFamily", "->", "\"\<Times\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.395151115125*^9, 3.395151116546875*^9}, 
   3.42472766171875*^9, 3.807478014391364*^9, {3.807478047895944*^9, 
   3.807478094879945*^9}, {3.807478690247505*^9, 3.8074786938340273`*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"2138e373-7d51-4e3b-badd-04d3cf7197cb"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwt0dsrg3Ecx/HfNuc5Ky7UTEmU5UKyib7fokZJjpfIQkY5pV2h5mLNBWlP
XCAXFMKDwgXFExEJkRYXDlskp4k2p4yx3/P71KfXH/CO1zWX1EoJIcr/e5UQ
744ECrEJntiiNa5xR/ilngpVfp8Fut5V5p7A1zVrEieHmNPCrKwtG6w88NQ1
yBM873OmDdBSj0FeflVuaNlnnkNK+8g6x50wr0E5YR0yWs6Yd7Ar4y3jPxew
Q3XAVY1ZrzLZma+wVNETM55zA4tUFzxapzJKXbfwQH2H/O5Q94HhHvKoX2DM
zTnUpT4x3WDLXM/dXHlm/kLx2Uz03PALFFEJxilsEea3V1BQJUi6Mqq0aieI
yvCw3rAYNegCUR8s5Law0/EGor5oP01X7qs+wEb1x+rJPr+knk8QDUBXfxDo
D77ASQ1EzerAglb+DWqqHBuaApLTatygpwbjfNaoUzbxAzw1BO0Dsdt2qQdE
w5DzqWwvSSDMcAy9XB6TbhFmOJJOY5mmVYKeDq8RKPaWotg7Ev8ALEfo7w==

       "]]},
     Annotation[#, "Charting`Private`Tag$24018#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[{{-0.09999999999999999, -0.5}, {-0.026028249030651086`, \
-0.1301412451532554}, {0.05826757073464903, 0.2913378536732451}, {
       0.13692271290300995`, 0.6846135645150495}, {0.22218207543361532`, 
       1.1109103771680766`}, {0.3058823930203427, 1.5294119651017135`}, {
       0.38394203301013086`, 1.9197101650506538`}, {0.4686058933621635, 
       2.3430294668108176`}, {0.547629076117257, 2.7381453805862845`}, {
       0.6332564792345949, 3.1662823961729742`}, {0.7173248374080549, 
       3.586624187040274}, {0.7957525179845756, 3.978762589922877}, {
       0.8807844189233408, 4.4039220946167035`}, {0.9000000000000001, 4.5}}]},
     Annotation[#, "Charting`Private`Tag$24018#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Times"},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{{{-1., 
       FormBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {0., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {1., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {2., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {3., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {4., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "4"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {5., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "5"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {-0.6989700043360189, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.5228787452803376, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.3979400086720377, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.30102999566398136`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.22184874961635648`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.1549019599857433, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.09691001300805668, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.04575749056067524, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      0.30102999566398114`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4771212547196624, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6020599913279623, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6989700043360186, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.7781512503836435, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8450980400142567, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9030899869919433, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9542425094393248, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.4771212547196624`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.6020599913279623`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.8450980400142567`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.4771212547196626`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.6020599913279625`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.845098040014257, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      3.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      3.4771212547196626`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      3.6020599913279625`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      3.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      3.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.845098040014257, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      3.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      3.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.301029995663981, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.477121254719663, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      4.6020599913279625`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.698970004336019, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.778151250383644, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.845098040014257, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.903089986991944, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.954242509439325, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {}}, {{{0., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {1., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {2., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {3., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {0.30102999566398114`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4771212547196624, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6020599913279623, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6989700043360186, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.7781512503836435, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8450980400142567, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9030899869919433, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9542425094393248, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.4771212547196624`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.6020599913279623`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.8450980400142567`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.4771212547196626`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.6020599913279625`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.845098040014257, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->216,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.0001, 3}, {-0.5, 4.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.807478048868578*^9, 3.807478073363132*^9}, 
   3.807478108652082*^9, 3.807478694402299*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"a6234db5-a6aa-4a68-90bf-06ac54658b68"]
}, Open  ]],

Cell[TextData[{
 "If, instead, you wish to use ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " or related ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions directly for your logarithmic plots, see the discussion below, \
under \[OpenCurlyDoubleQuote]Use with ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " and related functions\[CloseCurlyDoubleQuote]."
}], "Text",
 CellChangeTimes->{{3.614200948498361*^9, 3.614201004088439*^9}, {
  3.6142014869491153`*^9, 
  3.614201493389124*^9}},ExpressionUUID->"db1d383d-255d-476d-bd0f-\
20283d14d3f3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Automatic ticks for ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " plot functions"
}], "Subsubsection",
 CellChangeTimes->{{3.424727272421875*^9, 3.42472727859375*^9}, {
  3.424730401296875*^9, 
  3.424730407609375*^9}},ExpressionUUID->"d9d549fe-4fca-4c3a-ad4b-\
8cc92abda2ad"],

Cell[TextData[{
 "\tThe functions ",
 StyleBox["LinTicks",
  FontFamily->"Courier New"],
 " and ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " can also be specified as automatic tick generation functions for the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " plotting functions.  This saves you typing the plot range explicitly each \
time, at least if you do not wish to specify details such as the number of \
subdivisions."
}], "Text",
 CellChangeTimes->{{3.42472768440625*^9, 3.424727776*^9}, {
  3.42473041434375*^9, 
  3.4247304185625*^9}},ExpressionUUID->"2e42286e-0617-41f6-9561-5a7d2667345e"],

Cell["\<\
Plot[
    {Log10[Cosh[x]],Log10[Sinh[x]]},{x,0,10},
    PlotRange\[Rule]{{-0.0001,4},{-0.5,2.5}},
    FrameTicks\[Rule]{{LogTicks,None},{LinTicks,None}},
    Axes\[Rule]False,Frame\[Rule]True,ImageSize\[Rule]72*3
    ]\
\>", "Program",
 CellChangeTimes->{{3.3951510565625*^9, 3.395151062203125*^9}, 
   3.3951511525625*^9, 3.424727620046875*^9, {3.42472778403125*^9, 
   3.424727807609375*^9}, 3.516134894953125*^9, {3.6142025576386538`*^9, 
   3.6142025582076864`*^9}, 3.807478330900693*^9, {3.807478704585423*^9, 
   3.8074787063668203`*^9}},
 CellLabel->"In[96]:=",ExpressionUUID->"f3d1a483-73c5-4a3a-9a3d-3e27f7f2b130"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", 
       RowBox[{"Cosh", "[", "x", "]"}]}], "]"}], ",", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", 
       RowBox[{"Sinh", "[", "x", "]"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.0001"}], ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"LogTicks", ",", "None"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"LinTicks", ",", "None"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"72", "*", "3"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontFamily", "->", "\"\<Times\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.39515104653125*^9, 3.395151048890625*^9}, 
   3.4247276476875*^9, 3.42472781765625*^9, {3.807478165688116*^9, 
   3.807478176904571*^9}, {3.8074787154133472`*^9, 3.8074787184421787`*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"3d87b9d9-ca82-4f93-bfe7-f425062a981f"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwdkok71AkDx8fRrKPI2A2RGfMkwjpq3jbn91cWm5WHsLVqMTImZ3IvHUva
8vIiTYzc1vauI7Kkh0UjKTeFyLFGg5y5JpZR3t338zyf5/MPfDQ8L55iiZNI
JO+//afZVz3JRl4JFpvJt84H+kiaP+ul2Z2m+cCX+v3cEr3RYvt5w3Ua7UfU
SM3M5NHHLeRSqx/KDMZC8k7T3m7rVYts3n+oO2jxKJy6GeBNF4PeolfSNjsZ
lurW2ZnNMhiVy/m0NZCKuJ8fZl+xVsT++9JHNkV3MaOXzzQ12wt/87CAdWoG
yg45WG5raKCyj18otMzCZ9/X3/mzTBObfnYjy+xc3JqaIlc/00Ge2Ej8ulU+
RGoppU+MDPF1523NtYECLIsMujOsDmOaa9Mo9ClENNkofzL7CBK9Pp5bFf2K
8DhvyVwTE/SKLnCWqEVI/4tkVEg7hvAX6oaLFcX4UP+tRbqLJfbe6WtfsCzF
X7mRjMelVvDUISTm2OXIV+EaBDfaQlwU1S28/BBm045r5Gsn0cd32Se0qkBz
WOfnbgYOiCyVrVkZ+B0PtFdemB13gm3qFHklrxL8Yrqa+aQz1CIbnZd9qtDO
36VmnfEdeJYRS4uiR1CtN6/wYbjis+G3WgvUGhzzKxk8q8rEIK8+bH66BsrW
JiZjhp4ovs9tmquoxauXp34ctT8P+2B791nLOrw5xKZYFbKQJl2b9o79BBHF
nrLcKl9URdgGhyjz0Lv4QNS6yx9Zs1+prF7mQc2+vsX3YgACeyjsFatGSMkV
7tvQDAIlq0V8eeApDE93clYZIRDJVRcFmTXhKyVuuIFEKCZifnFYymuCk5pP
fGZ/KKrZV3MWfZ7h93YtG9LNcLgeZpi8FzUjNyrNZEw1CvltuZfmqK04WJFD
u0qOgZD7SGcssRXTnIeJAfdiYM1uF7zaaMWXg4oeLYaxmJdYd6ntbYPfwTxh
ndd1HDW3N4m/2YE3XdKG/565gZ7yLXGtxW5YvMf7BVYCKJB226Xfg6Bk1l5d
WiJMD3BMbnr14KQZ5VDzSCKShEWrUS978CJ7hrrzhyQwbvezPEtegi3PpE7U
peBam56tkXsvvowIibmhwMFvFY8PlNztxbuxWF+7GA5ecY9LaHb04nXbkQPG
KxzsZ5+pUzbuQyldnhczcBdtEnH6JMV+vN1+I2goT8ce82FK9/PXeBJofdIj
LRNl5fHD/vpDKE4cq+OrFmCWMptoyxxCmtiGf55HAbTCbS20OUNYkT6oN/Br
AfLMZPMFG0NIb3Ar/83oF6S2Jnq7Ng/jzFJDVq99IcIFycs250bRzIh5TM69
j1zZ9usKVnzw/WIWeZwSWJhHn/vJjY+JTp+MznclGAnU/ddiBB8W73QSbExL
ofwqYaqjmI+MYsdPMYJS3Obanbi1exwK5d/SpYzLcF2zS257eBxrdEdfqb8/
Z+NlxnywAIs2s8QEsxKkgrXa4QQB9ruw72ylVIIrqTbSVijABXF59695lWhp
9VYvei3AcuM9HpNaBW3nrQKWyQSMBenHu8eqMH1Bq/RPsUmEeKhNOPpUwzf1
SkNPyhTM9fych7JrEDh5UFBVNoOgw0Y5isd5kNGI0xo7uoQ/RKqbelUtSNrd
rpPvsYq7HqxI+6c98Bx2fiLRsQb5WsKONdWPS81xnhe1NuH6zc+NlYxhVATt
dFI+8RFne4n/GmjzkR/tN2t4mkSoUE+4Htt6i9jcLUfhvBiRHEDu7iuaBKmX
T9RFSRDc0Ea6uMM0DoR6Rzrr7CDGry3JX2TMYeJD+ney9WRCLJ925ujsAmwn
fa+kXpIirgXduKQfuAT7iRRddXUZ4oXmfMTu8WXMNnn+1PJAligIpZPcTVeh
r/B6n6X7LkKF5f/AplIIGXxgjqzKESElSjkulDXYLLiu0112E7pVbJfRpHUM
PvUSc9VTIKL9B/qTJDfw6NYzN9oHBcJkKZtpytyE944wflcXhVD6NHHWfliE
88HRj3beUySCyhn7ncw+woCt22XH/Jyg055rBqR9QjdFTzbM+AvCJtNPUUgm
EX+UxWbqSewhdmYyu7SqSUS0mI5Dx+geQvMU1182VIyQGYn6JrBKiXBq/SgT
qS9OTN7X4OReViaU9xxRch0RJzjaKpI1LipEVqxc0RxXgghghI+xOlQI0v+R
JP4HP0sCiA==
       "]]},
     Annotation[#, "Charting`Private`Tag$24392#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwBUQOu/CFib1JlAgAAADQAAAACAAAALM+Ru5zq0z8AAAAAAADgvyRnWLwY
OdQ/ssp//XKP37/KA4QuABPVP0pN73f7X96/Fj3bEs/G1j+PQhDIyCHcv66v
idtsLto/HpR9hbQS2L/qEuqMSmHaP7LYcQHr2de/J3ZKPiiU2j8dD4Qsg6HX
v6A8C6Hj+do/knBVc9Ix17+SyYxmWsXbP4xQkdbDVta/duOP8Udc3T8o2u71
w7DUv58Ly4MRReA/mCg8HyGd0b8+PXtcgF7gP4LDCukebtG/3G4rNe934D85
0TI9Wj/RvxjSi+bMquA/+19IUYbi0L+RmExJiBDhPwzrhIyeK9C/gyXODv/b
4T+hdIvvWpDNv2c/0ZnscuM/J3X3KqBMyL8Aova624vjPzpt5Ory/Me/mAQc
3Mqk4z+JbV2rla3Hv8jJZh6p1uM/UjyrpMcPx78oVPyiZTrkPzKE43HF18W/
6GgnrN4B5T/OzmKBcnXDv2qSfb7QkOY/wtfF++nEvb9u5SnjtK7pP+PIEc4x
hqm/CiGEJ9848D+EQLLSzfezP44QyyqhYPM/6rj8dJegxz9i21S/A8z2P9jT
5If6rdI/ccWEYm8n+j/btDuJKxfZP7FwDFMYSf0/C3Tam1ji3j+he2vqMFcA
QA/f5JKOhOI/gp/8UfTsAUDI75VMTFnlPwDT4EC8egNAZOozXmYZ6D8mdGZ4
VCoFQGX9/WCbEOs/5PWXVgu9BkC4mPTtCtLtP0rlan2ScQhADNMB2Elm8D9O
5JArHh4KQK6Uq9ne2/E/6sNigMitC0DTtMoK2zfzPy4R1h1DXw1ACYB/Uvqw
9D8KP/Vh3PMOQBeddKDIEPY/R+1a9yJVEECmNSCb2o33P9jCZAFaLBFAAQSx
5eQD+T+1iMReIPURQPuOwJHIYPo/ZgV14M7OEkAYOHJPA9v7P2Nye7UMmhNA
RMt0riA8/T8vZyvOTGEUQEx9YfRKlv4/zxIsC3U5FUCtYv7d6AYAQLuugpss
AxZAk5NUPyC2AEB7ASpQzN0WQE5hC34GdAFACtx6SG60F0BZvsbMdC4CQOWm
IZSffBhAG8Kr5VfcAkCUKBkEuVUZQDtVlDnqmANAwleNNWfMGUAAAAAAAAAE
QLzun3s=
       "]]},
     Annotation[#, "Charting`Private`Tag$24392#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Times"},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{{{-1., 
       FormBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {0., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {1., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {2., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {3., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {-0.6989700043360189, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.5228787452803376, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.3979400086720377, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.30102999566398136`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.22184874961635648`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.1549019599857433, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.09691001300805668, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.04575749056067524, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      0.30102999566398114`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4771212547196624, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6020599913279623, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6989700043360186, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.7781512503836435, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8450980400142567, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9030899869919433, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9542425094393248, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.4771212547196624`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.6020599913279623`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.8450980400142567`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.4771212547196626`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.6020599913279625`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.845098040014257, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {}}, {{{0., 
       FormBox["\"0\"", TraditionalForm], {0.01, 0}, {}}, {1., 
       FormBox["\"1\"", TraditionalForm], {0.01, 0}, {}}, {2., 
       FormBox["\"2\"", TraditionalForm], {0.01, 0}, {}}, {3., 
       FormBox["\"3\"", TraditionalForm], {0.01, 0}, {}}, {4., 
       FormBox["\"4\"", TraditionalForm], {0.01, 0}, {}}, {0.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6000000000000001, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->216,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.0001, 4}, {-0.5, 2.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.42472781853125*^9, {3.807478166553611*^9, 3.807478178188175*^9}, 
   3.807478324885376*^9, 3.80747871884585*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"4960cea2-a1b7-474d-b802-124774be77f5"]
}, Open  ]],

Cell[TextData[{
 "\tWhat if you wish to have tick marks on the top and right as well, but \
without labels on them?  Simply specifying ",
 StyleBox["FrameTicks\[Rule]{LinTicks,LogTicks}",
  FontFamily->"Courier New"],
 " or ",
 StyleBox["FrameTicks\[Rule]{LinTicks,LogTicks,LinTicks,LogTicks}",
  FontFamily->"Courier New"],
 " would unfortunately result in ticks with unsightly and redundant labels.  \
This can be avoided with the CustomTicks ",
 StyleBox["StripTickLabels",
  FontFamily->"Courier New"],
 " wrapper function, as shown below."
}], "Text",
 CellChangeTimes->{{3.4247296204375*^9, 3.424729741734375*^9}, {
  3.424729775875*^9, 3.424729877875*^9}, {3.4247302263125*^9, 
  3.42473023909375*^9}, {3.8074794800747957`*^9, 
  3.807479480955998*^9}},ExpressionUUID->"c1134898-a1b1-4978-8033-\
a8d13e2eb432"],

Cell["\<\
Plot[
    {Log10[Cosh[x]],Log10[Sinh[x]]},{x,0,10},
    PlotRange\[Rule]{{-0.0001,4},{-0.5,2.5}},
    FrameTicks\[Rule]{{LogTicks,StripTickLabels[LogTicks]},{LinTicks,\
StripTickLabels[LinTicks]}},
    Axes\[Rule]False,Frame\[Rule]True,ImageSize\[Rule]72*3
    ]\
\>", "Program",
 CellChangeTimes->{{3.39515104653125*^9, 3.395151048890625*^9}, 
   3.4247276476875*^9, 3.42472781765625*^9, {3.424729693453125*^9, 
   3.424729698109375*^9}, {3.424729751109375*^9, 3.42472976896875*^9}, {
   3.424729948625*^9, 3.4247299561875*^9}, {3.4247314673125*^9, 
   3.424731485171875*^9}, 3.516134901390625*^9, {3.614202565856124*^9, 
   3.6142025663111496`*^9}, 3.807478370412574*^9, {3.8074787301053963`*^9, 
   3.8074787324850817`*^9}},
 CellLabel->
  "In[189]:=",ExpressionUUID->"7367643d-969a-47c7-b818-a7e1b2d4863e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", 
       RowBox[{"Cosh", "[", "x", "]"}]}], "]"}], ",", 
     RowBox[{"Log", "[", 
      RowBox[{"10", ",", 
       RowBox[{"Sinh", "[", "x", "]"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.0001"}], ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.5"}], ",", "2.5"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"LogTicks", ",", 
        RowBox[{"StripTickLabels", "[", "LogTicks", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"LinTicks", ",", 
        RowBox[{"StripTickLabels", "[", "LinTicks", "]"}]}], "}"}]}], "}"}]}],
    ",", "\[IndentingNewLine]", 
   RowBox[{"Axes", "\[Rule]", "False"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"72", "*", "3"}]}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontFamily", "->", "\"\<Times\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.39515104653125*^9, 3.395151048890625*^9}, 
   3.4247276476875*^9, 3.42472781765625*^9, {3.424729693453125*^9, 
   3.424729698109375*^9}, {3.424729751109375*^9, 3.42472976896875*^9}, {
   3.424729948625*^9, 3.4247299561875*^9}, {3.8074783440497828`*^9, 
   3.807478358240354*^9}, 3.807478748729333*^9},
 CellLabel->"In[32]:=",ExpressionUUID->"6738f218-2c40-4c4b-9079-52e3ec9d70d6"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwdkok71AkDx8fRrKPI2A2RGfMkwjpq3jbn91cWm5WHsLVqMTImZ3IvHUva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       "]]},
     Annotation[#, "Charting`Private`Tag$24605#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwBUQOu/CFib1JlAgAAADQAAAACAAAALM+Ru5zq0z8AAAAAAADgvyRnWLwY
OdQ/ssp//XKP37/KA4QuABPVP0pN73f7X96/Fj3bEs/G1j+PQhDIyCHcv66v
idtsLto/HpR9hbQS2L/qEuqMSmHaP7LYcQHr2de/J3ZKPiiU2j8dD4Qsg6HX
v6A8C6Hj+do/knBVc9Ix17+SyYxmWsXbP4xQkdbDVta/duOP8Udc3T8o2u71
w7DUv58Ly4MRReA/mCg8HyGd0b8+PXtcgF7gP4LDCukebtG/3G4rNe934D85
0TI9Wj/RvxjSi+bMquA/+19IUYbi0L+RmExJiBDhPwzrhIyeK9C/gyXODv/b
4T+hdIvvWpDNv2c/0ZnscuM/J3X3KqBMyL8Aova624vjPzpt5Ory/Me/mAQc
3Mqk4z+JbV2rla3Hv8jJZh6p1uM/UjyrpMcPx78oVPyiZTrkPzKE43HF18W/
6GgnrN4B5T/OzmKBcnXDv2qSfb7QkOY/wtfF++nEvb9u5SnjtK7pP+PIEc4x
hqm/CiGEJ9848D+EQLLSzfezP44QyyqhYPM/6rj8dJegxz9i21S/A8z2P9jT
5If6rdI/ccWEYm8n+j/btDuJKxfZP7FwDFMYSf0/C3Tam1ji3j+he2vqMFcA
QA/f5JKOhOI/gp/8UfTsAUDI75VMTFnlPwDT4EC8egNAZOozXmYZ6D8mdGZ4
VCoFQGX9/WCbEOs/5PWXVgu9BkC4mPTtCtLtP0rlan2ScQhADNMB2Elm8D9O
5JArHh4KQK6Uq9ne2/E/6sNigMitC0DTtMoK2zfzPy4R1h1DXw1ACYB/Uvqw
9D8KP/Vh3PMOQBeddKDIEPY/R+1a9yJVEECmNSCb2o33P9jCZAFaLBFAAQSx
5eQD+T+1iMReIPURQPuOwJHIYPo/ZgV14M7OEkAYOHJPA9v7P2Nye7UMmhNA
RMt0riA8/T8vZyvOTGEUQEx9YfRKlv4/zxIsC3U5FUCtYv7d6AYAQLuugpss
AxZAk5NUPyC2AEB7ASpQzN0WQE5hC34GdAFACtx6SG60F0BZvsbMdC4CQOWm
IZSffBhAG8Kr5VfcAkCUKBkEuVUZQDtVlDnqmANAwleNNWfMGUAAAAAAAAAE
QLzun3s=
       "]]},
     Annotation[#, "Charting`Private`Tag$24605#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Times"},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{{{-1., 
       FormBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {0., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {1., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {2., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {3., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {-0.6989700043360189, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.5228787452803376, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.3979400086720377, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.30102999566398136`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.22184874961635648`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.1549019599857433, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.09691001300805668, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.04575749056067524, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      0.30102999566398114`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4771212547196624, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6020599913279623, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6989700043360186, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.7781512503836435, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8450980400142567, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9030899869919433, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9542425094393248, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.4771212547196624`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.6020599913279623`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.8450980400142567`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.4771212547196626`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.6020599913279625`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.845098040014257, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{-1., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {0., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {1., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {2., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {3., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {-0.6989700043360189, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.5228787452803376, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.3979400086720377, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.30102999566398136`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.22184874961635648`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.1549019599857433, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.09691001300805668, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.04575749056067524, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      0.30102999566398114`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4771212547196624, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6020599913279623, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6989700043360186, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.7781512503836435, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8450980400142567, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9030899869919433, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.9542425094393248, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.4771212547196624`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.6020599913279623`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.8450980400142567`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.3010299956639813`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.4771212547196626`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.6020599913279625`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.6989700043360187`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.7781512503836434`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.845098040014257, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9030899869919433`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9542425094393248`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}}, {{{0., 
       FormBox["\"0\"", TraditionalForm], {0.01, 0}, {}}, {1., 
       FormBox["\"1\"", TraditionalForm], {0.01, 0}, {}}, {2., 
       FormBox["\"2\"", TraditionalForm], {0.01, 0}, {}}, {3., 
       FormBox["\"3\"", TraditionalForm], {0.01, 0}, {}}, {4., 
       FormBox["\"4\"", TraditionalForm], {0.01, 0}, {}}, {0.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6000000000000001, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{0., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {1., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {2., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {3., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {4., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {0.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6000000000000001, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->216,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.0001, 4}, {-0.5, 2.5}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.424729699078125*^9, {3.42472975165625*^9, 3.424729769453125*^9}, 
   3.42472988265625*^9, 3.8074783610110397`*^9, 3.807478749943487*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"a2f5e506-44f9-44fb-bb42-ad0a9bc2617e"]
}, Open  ]],

Cell[TextData[{
 "If you are doing many such plots, it is easiest to set the necessary \
options as the default options for ",
 StyleBox["Plot",
  FontFamily->"Courier New"],
 "."
}], "Text",
 CellChangeTimes->{{3.424729999703125*^9, 3.4247300188125*^9}, {
  3.4247302100625*^9, 
  3.42473021253125*^9}},ExpressionUUID->"10594554-f427-43fa-b156-\
65e5950fc2f5"],

Cell["\<\
SetOptions[
  Plot,
  Axes\[Rule]False,Frame\[Rule]True,
  FrameTicks\[Rule]{{LogTicks,StripTickLabels[LogTicks]},{LinTicks,\
StripTickLabels[LinTicks]}}
];
GraphicsGrid[{{Plot[Log10[x^2],{x,0,10}],Plot[Log10[x^-2],{x,0,10}]}}]\
\>", "Program",
 CellChangeTimes->{{3.424729960359375*^9, 3.424729964*^9}, {
   3.42473003846875*^9, 3.424730186328125*^9}, {3.424730256921875*^9, 
   3.424730320734375*^9}, {3.424731562421875*^9, 3.42473160075*^9}, 
   3.5161349083125*^9, {3.6142025699743595`*^9, 3.6142025705483923`*^9}, {
   3.807478400883707*^9, 3.807478408028891*^9}, {3.807478757193356*^9, 
   3.8074787966162863`*^9}},
 CellLabel->
  "In[206]:=",ExpressionUUID->"5363ab65-490d-4d12-81cf-623c02e9cfc7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"Plot", ",", 
    RowBox[{"Axes", "\[Rule]", "False"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"FrameTicks", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"LogTicks", ",", 
         RowBox[{"StripTickLabels", "[", "LogTicks", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"LinTicks", ",", 
         RowBox[{"StripTickLabels", "[", "LinTicks", "]"}]}], "}"}]}], 
      "}"}]}], ",", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"FontFamily", "->", "\"\<Times\>\""}], "}"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{"10", ",", 
          RowBox[{"x", "^", "2"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "10"}], "}"}]}], "]"}], ",", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"Log", "[", 
         RowBox[{"10", ",", 
          RowBox[{"x", "^", 
           RowBox[{"-", "2"}]}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", "10"}], "}"}]}], "]"}]}], "}"}], "}"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"5", "*", "72"}]}]}], "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.424729960359375*^9, 3.424729964*^9}, {
   3.42473003846875*^9, 3.424730186328125*^9}, {3.424730256921875*^9, 
   3.424730260734375*^9}, {3.4247303266875*^9, 3.42473032909375*^9}, 
   3.807478396367681*^9, {3.8074784799585257`*^9, 3.8074784835531178`*^9}, 
   3.807478802902134*^9, {3.8074824179080667`*^9, 3.8074824549129963`*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"93f7f39f-8965-4617-88bf-fab829be37cb"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], LineBox[CompressedData["
1:eJwVxXk81HkfAHCMdltUhl2V3L9QSKenEJ/vUipKRVOOVhnH0LkqqeiiGj0i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           "]]},
         Annotation[#, "Charting`Private`Tag$16293#1"]& ]}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      BaseStyle->{FontFamily -> "Times"},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{{{-2., 
           FormBox[
            TagBox[
             SuperscriptBox["10", 
              RowBox[{"-", "2"}]], DisplayForm], TraditionalForm], {
           0.01, 0}, {}}, {-1., 
           FormBox[
            TagBox[
             SuperscriptBox["10", 
              RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {
           0.01, 0}, {}}, {0., 
           FormBox[
            TagBox[
             SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {
           0.01, 0}, {}}, {1., 
           FormBox[
            TagBox[
             SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {
           0.01, 0}, {}}, {2., 
           FormBox[
            TagBox[
             SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {
           0.01, 0}, {}}, {3., 
           FormBox[
            TagBox[
             SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {
           0.01, 0}, {}}, {-1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.5228787452803376`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.3979400086720377`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.2218487496163566`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.1549019599857433`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.0969100130080567`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.0457574905606752`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.6989700043360189, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.5228787452803376, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.3979400086720377, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.30102999566398136`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.22184874961635648`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.1549019599857433, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.09691001300805668, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.04575749056067524, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.30102999566398114`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.4771212547196624, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.6020599913279623, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.6989700043360186, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.7781512503836435, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.8450980400142567, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.9030899869919433, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.9542425094393248, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.4771212547196624`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.6020599913279623`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.7781512503836434`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.8450980400142567`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.9030899869919433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.9542425094393248`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.4771212547196626`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.6020599913279625`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.7781512503836434`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.845098040014257, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.9030899869919433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.9542425094393248`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{-2., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {-1., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {0., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {1., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {2., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {3., 
           FormBox["\"\"", TraditionalForm], {
           0.01, 0}, {}}, {-1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.5228787452803376`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.3979400086720377`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.2218487496163566`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.1549019599857433`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.0969100130080567`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.0457574905606752`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.6989700043360189, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.5228787452803376, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.3979400086720377, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.30102999566398136`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.22184874961635648`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.1549019599857433, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.09691001300805668, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.04575749056067524, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.30102999566398114`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.4771212547196624, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.6020599913279623, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.6989700043360186, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.7781512503836435, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.8450980400142567, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.9030899869919433, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.9542425094393248, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.4771212547196624`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.6020599913279623`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.7781512503836434`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.8450980400142567`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.9030899869919433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.9542425094393248`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.4771212547196626`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.6020599913279625`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.7781512503836434`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.845098040014257, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.9030899869919433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          2.9542425094393248`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}}, {{{0., 
           FormBox["\" 0\"", TraditionalForm], {0.01, 0}, {}}, {2., 
           FormBox["\" 2\"", TraditionalForm], {0.01, 0}, {}}, {4., 
           FormBox["\" 4\"", TraditionalForm], {0.01, 0}, {}}, {6., 
           FormBox["\" 6\"", TraditionalForm], {0.01, 0}, {}}, {8., 
           FormBox["\" 8\"", TraditionalForm], {0.01, 0}, {}}, {10., 
           FormBox["\"10\"", TraditionalForm], {0.01, 0}, {}}, {0.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {7., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {7.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {8.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {9., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {9.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{0., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {2., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {4., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {6., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {8., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {10., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {0.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {7., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {7.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {8.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {9., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {9.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{24.8515625, 3.000000000000057}, {15., 
       15.000000000000028`}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 10}, {-1.4104117472020161`, 1.9999999822736942`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {192., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], LineBox[CompressedData["
1:eJwV0fs/1PkewHGMdlskl13bxf0byq2rLWTen25CpdCUS0vGZXRflUropqIj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           "]]},
         Annotation[#, "Charting`Private`Tag$16573#1"]& ]}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      BaseStyle->{FontFamily -> "Times"},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{{{-3., 
           FormBox[
            TagBox[
             SuperscriptBox["10", 
              RowBox[{"-", "3"}]], DisplayForm], TraditionalForm], {
           0.01, 0}, {}}, {-2., 
           FormBox[
            TagBox[
             SuperscriptBox["10", 
              RowBox[{"-", "2"}]], DisplayForm], TraditionalForm], {
           0.01, 0}, {}}, {-1., 
           FormBox[
            TagBox[
             SuperscriptBox["10", 
              RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {
           0.01, 0}, {}}, {0., 
           FormBox[
            TagBox[
             SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {
           0.01, 0}, {}}, {1., 
           FormBox[
            TagBox[
             SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {
           0.01, 0}, {}}, {2., 
           FormBox[
            TagBox[
             SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {
           0.01, 0}, {}}, {-2.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-2.5228787452803374`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-2.3979400086720375`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-2.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-2.2218487496163566`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-2.154901959985743, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-2.0969100130080567`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-2.0457574905606752`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.5228787452803376`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.3979400086720377`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.2218487496163566`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.1549019599857433`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.0969100130080567`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.0457574905606752`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.6989700043360189, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.5228787452803376, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.3979400086720377, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.30102999566398136`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.22184874961635648`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.1549019599857433, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.09691001300805668, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.04575749056067524, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.30102999566398114`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.4771212547196624, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.6020599913279623, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.6989700043360186, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.7781512503836435, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.8450980400142567, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.9030899869919433, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.9542425094393248, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.4771212547196624`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.6020599913279623`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.7781512503836434`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.8450980400142567`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.9030899869919433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.9542425094393248`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{-3., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {-2., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {-1., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {0., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {1., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {2., 
           FormBox["\"\"", TraditionalForm], {
           0.01, 0}, {}}, {-2.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-2.5228787452803374`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-2.3979400086720375`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-2.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-2.2218487496163566`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-2.154901959985743, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-2.0969100130080567`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-2.0457574905606752`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.5228787452803376`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.3979400086720377`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.2218487496163566`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.1549019599857433`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.0969100130080567`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-1.0457574905606752`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.6989700043360189, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.5228787452803376, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.3979400086720377, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.30102999566398136`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.22184874961635648`, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.1549019599857433, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.09691001300805668, 
           FormBox["\"\"", TraditionalForm], {
           0.005, 0}, {}}, {-0.04575749056067524, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.30102999566398114`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.4771212547196624, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.6020599913279623, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.6989700043360186, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.7781512503836435, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.8450980400142567, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.9030899869919433, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          0.9542425094393248, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.3010299956639813`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.4771212547196624`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.6020599913279623`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.6989700043360187`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.7781512503836434`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.8450980400142567`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.9030899869919433`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
          1.9542425094393248`, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}}, {{{0., 
           FormBox["\" 0\"", TraditionalForm], {0.01, 0}, {}}, {2., 
           FormBox["\" 2\"", TraditionalForm], {0.01, 0}, {}}, {4., 
           FormBox["\" 4\"", TraditionalForm], {0.01, 0}, {}}, {6., 
           FormBox["\" 6\"", TraditionalForm], {0.01, 0}, {}}, {8., 
           FormBox["\" 8\"", TraditionalForm], {0.01, 0}, {}}, {10., 
           FormBox["\"10\"", TraditionalForm], {0.01, 0}, {}}, {0.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {7., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {7.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {8.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {9., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {9.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{0., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {2., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {4., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {6., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {8., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {10., 
           FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {0.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {7., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {7.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {8.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {9., 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {9.5, 
           FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->{{24.8515625, 3.000000000000057}, {15., 
       15.000000000000028`}},
      Method->{
       "DefaultBoundaryStyle" -> Automatic, 
        "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
        "DefaultMeshStyle" -> AbsolutePointSize[6], "ScalingFunctions" -> 
        None, "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 10}, {-1.9999999822736942`, 1.2035447261209216`}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {576., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}]}, {}},
  ImageSize->360,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.807478416158338*^9, 3.807478444566204*^9}, 
   3.807478803595544*^9, {3.8074823941414003`*^9, 3.8074824554682083`*^9}},
 CellLabel->"Out[23]=",ExpressionUUID->"d7609fb7-47fe-4ef4-81d9-ba15513bd96e"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<OptionSummaryWideDescription\>\"", ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<LogPlot\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<False\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Controls whether \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<LogTicks\>\"", "]"}], ",", 
      "\"\<operates as it should for standalone use or for automatic tick \
mark generation with Mathematica's \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<LogPlot\>\"", "]"}]}], "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}],
   ";"}], "\n", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"texttt", "[", "\"\<LogTicks\>\"", "]"}], ",", 
     "\"\< special option.\>\""}], "}"}], "]"}], 
  ";"}], "\[IndentingNewLine]"}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.516135363625*^9, 3.516135492234375*^9}, {
  3.5161355373125*^9, 3.516135567359375*^9}},
 Hyphenation->False,
 CellLabel->"In[17]:=",ExpressionUUID->"8258f662-6ecc-49fd-b088-5b9ef7776ef0"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       StyleBox[
        RowBox[{"option", " ", "name"}], "SO10"], 
       StyleBox[
        RowBox[{"default", " ", "value"}], "SO10"], ""},
      {
       StyleBox["LogPlot",
        FontFamily->"Courier"], 
       StyleBox["False",
        FontFamily->"Courier"], 
       RowBox[{"Controls", " ", "whether", " ", 
        StyleBox["LogTicks",
         FontFamily->"Courier"], "operates", " ", "as", " ", "it", " ", 
        "should", " ", "for", " ", "standalone", " ", "use", " ", "or", " ", 
        "for", " ", "automatic", " ", "tick", " ", "mark", " ", "generation", 
        " ", "with", " ", 
        RowBox[{"Mathematica", "'"}], "s", " ", 
        StyleBox["LogPlot",
         FontFamily->"Courier"]}]}
     }]], "3ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.23], 
       Scaled[0.23], {
        Scaled[0.5]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.51613557096875*^9},ExpressionUUID->"f8f1b1b1-d8bd-4559-89ec-546a2d8fb668"],

Cell[TextData[{
 StyleBox["LogTicks",
  FontFamily->"Courier"],
 " special option."
}], "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.516135571015625*^9},ExpressionUUID->"0bfd5728-f775-4436-8b83-\
9d888501bef6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Use with ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " and related functions"
}], "Subsubsection",
 CellChangeTimes->{
  3.61420151898416*^9},ExpressionUUID->"2162b609-0e3d-46f6-800c-f79df05be618"],

Cell[TextData[{
 "\tIf you wish to use ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " or related ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions directly for your logarithmic plots, you may also do so.  \
However, ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " must then be instructed to adjust its output accordingly.  (",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " expects tick coordinates to be specified as the true coordinate value, not \
the logarithm of the coordinate value.  ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " must also interpret its ",
 StyleBox["n1",
  FontSlant->"Italic"],
 " and ",
 StyleBox["n2",
  FontSlant->"Italic"],
 " arguments differently in this case.)  Automatic use with ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " can be accomplished by setting the option ",
 StyleBox["LogPlot->True",
  FontFamily->"Courier New"],
 "."
}], "Text",
 CellChangeTimes->{{3.424729999703125*^9, 3.4247300188125*^9}, {
   3.4247302100625*^9, 3.42473021253125*^9}, {3.51613501165625*^9, 
   3.5161352076875*^9}, {3.516135591578125*^9, 3.516135662328125*^9}, {
   3.51613603228125*^9, 3.516136032703125*^9}, {3.5161361073125*^9, 
   3.516136130953125*^9}, 
   3.6142015257491693`*^9},ExpressionUUID->"0fab764b-24b3-43c3-8868-\
11af346110a2"],

Cell["\<\
SetOptions[LogTicks, LogPlot -> True];
Plot[
 {Cosh[x], Sinh[x]}, {x, 0, 10},
 PlotRange->{{-0.0001, 4},{10^-0.5, 10^2.5}},
 FrameTicks->{{LogTicks,StripTickLabels[LogTicks]},{LinTicks,StripTickLabels[\
LinTicks]}},
 Frame->True, ImageSize -> 72*3
 ]\
\>", "Program",
 CellChangeTimes->{{3.39515104653125*^9, 3.395151048890625*^9}, 
   3.4247276476875*^9, 3.42472781765625*^9, {3.424729693453125*^9, 
   3.424729698109375*^9}, {3.424729751109375*^9, 3.42472976896875*^9}, {
   3.424729948625*^9, 3.4247299561875*^9}, {3.51613517521875*^9, 
   3.51613523584375*^9}, 3.51613532775*^9, 3.516135954515625*^9, {
   3.807478832593772*^9, 3.807478856608376*^9}, {3.807478984376956*^9, 
   3.807478996009008*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"7f5bfd74-8f2e-419e-9ec2-11d3ea59b51f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"LogTicks", ",", 
    RowBox[{"LogPlot", "->", "True"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"LogPlot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cosh", "[", "x", "]"}], ",", 
     RowBox[{"Sinh", "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "4"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.0001"}], ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"10", "^", 
         RowBox[{"-", "0.5"}]}], ",", 
        RowBox[{"10", "^", "2.5"}]}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"LogTicks", ",", 
        RowBox[{"StripTickLabels", "[", "LogTicks", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"LinTicks", ",", 
        RowBox[{"StripTickLabels", "[", "LinTicks", "]"}]}], "}"}]}], "}"}]}],
    ",", "\[IndentingNewLine]", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"72", "*", "3"}]}]}], "\[IndentingNewLine]", "]"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.39515104653125*^9, 3.395151048890625*^9}, 
   3.4247276476875*^9, 3.42472781765625*^9, {3.424729693453125*^9, 
   3.424729698109375*^9}, {3.424729751109375*^9, 3.42472976896875*^9}, {
   3.424729948625*^9, 3.4247299561875*^9}, {3.51613517521875*^9, 
   3.51613523584375*^9}, {3.516135863421875*^9, 3.51613593571875*^9}, 
   3.807478884367428*^9, {3.807478959206664*^9, 3.8074790016844997`*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"fd4575c7-9ddf-4119-bf38-9c227a0ef3dc"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVk2k41Hsfh+1mBvOPtIy1bJWGpKzJ91cqUpEtJzQRZalTREWyFaXMlHPS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       "]]},
     Annotation[#, "Charting`Private`Tag$27483#1"]& ], 
    TagBox[
     {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwV0fk71AkcwHEzhjFfxzey26McO5ZylGyFKH0+1aJyPJmI3SSPSnJUoixP
Ja2jwmo3KSlLjpIrclTka6M8WmfDaDTOSDKMyTGMGtv+8H5ef8Cb7XuSc5Qu
Jye391v/WyH1VEkRc+E794rq0sDPlKHr5Mf6hE7wcIvX542KqZVRDjbHsjqh
z+h2SwhPTC0rykwgqjqhaOeDCN2XYkqqtM/MdagTpq5H7nh4T0y111WF9m3u
AgFLXBLvLaYizaNl8yNdcNUz/4et/CmqldTUNMNueN4mm/B5LKLCW63h1gwf
0nvaiGmakFIzqxhpUuqB/rEd8zWj41ROknnionYPVDYG6KW1jFMdTmv43nY9
cN/0SE582jhl+q9mqGFqD8jGcn+12TBO9TeK8sqs3kH4ei1Br98nyuGfXLWW
SAEMZNObjgg+UivK1ftotH4wPU9v8poeoSqHdja3bR2CUX+JrYXDAPUi4O6q
X4TD4B3JSBGX8qjZ1bZkUfAoyE88uNFY0EzRFwqWrTL8BC3+sqPCd1WU5ZJP
5b5iIYDgUHtSxA1ojtnU+spEBFmaycvF2+tA79r4Qv7kFPgKyjqeurTCuKS/
r8v8M5iddw0KDu2CnE/Vr9X+mAZ2ZF2tt4oA1HTui4aHZyBotelXqckgJB6v
8Ms0mAMLK3uXKuYwzGHBsH+UBN48YXvt1xiFsA0N5d/Xz0N21VbxWcEY9Bc3
JHSwpdDjbmDL5QlhMaAz3ThyEfKYY3ZZT0Vgup0p86v+Aqmu8eHtP4nB4R77
WOkKGXT5MG5ZZX6GcJ1D+oNeS/CGb80snZ6GtUJ35W5nOSwbubQtaNssLCen
lBqkchhXn7oA2XPAoNJLfrxDQ4mGc13hpAQCN1XzWY507D6Td/iU2wIU7PbN
rJ2j4x2Pwi0hZVKYHV+57EOqPIp6gTMvWYSKfQ7yKT8z8K+TMYS+51eI2hX7
d/kHBhoHKl8wz5QBu3fP2+xYBdRJe8yzHVwCG6uYFK0NikgN7vw9MUMOvXTb
FmhcRbzyProwA2k4+zpp6FQ0E5uf0+P0pmh4i+EdxjFQwvs3w8b41+m4vK/i
Hr1BCWubS9NhkzwqnI92sw5hoYdiZabOkDzK5XuXDGkQWBN15bJjDANP3y5J
0nhBIKdNArMbFfC56WUl9RPKaLL3RJHngAKq7zm99pKaCupzkvla0YooWNfO
jahRwbRhI8sD65n4KAMMhr1VcaSL82Gpg4kHSyzVdWSq2GoDz46HKOHF2Kxo
wUM1ZDtn7d6vy8Kijzrpak4kmtq1GRZSLLx8N9anz4XE1KOnL5x7wcIjnAnD
YlcSw/SLeU4vWahdU/PI2YNE3vWp2InXLLyafOBVoi+Jjjb5/WY8FvpbpomJ
CBL3ahldLBWyUD9Gcxczj8Q0FfvwSi0CZZvPqXY/IHEgP7Y+TptA/sT7N3kF
JEbd9CM99Ai85vH4oH0pidnBqnkSAwKXTDihsTUkHsa51s3mBAo6kjPkuSRK
a4PJansCn8RJDnO7SOw1HnRP2E1gypZDxtlvScyVLKQfcCLQMdesfEcfiZ7P
tNd8cSXw2W8tTdFjJJ5pXGdte5DA1HUWya5CEr9YcM+p+hAYMnTHjS0isXZJ
r67Xl0Ajp6D+uhkSu+8+srvgTyCD1plzTULixsmZeJdAAgcqtgT4SEnk/jnY
pHvi28eA7PXmX0l0fnVWWXSKwJt6yrNLSySymsqdqFAC/wNnE2t3
       "]]},
     Annotation[#, "Charting`Private`Tag$27483#2"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, -1.1512925464970227`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{{{-2.3025850929940455`, 
       FormBox[
        TagBox[
         SuperscriptBox["10", 
          RowBox[{"-", "1"}]], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {0., 
       FormBox[
        TagBox[
         SuperscriptBox["10", "0"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {2.302585092994046, 
       FormBox[
        TagBox[
         SuperscriptBox["10", "1"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {4.605170185988092, 
       FormBox[
        TagBox[
         SuperscriptBox["10", "2"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {6.907755278982137, 
       FormBox[
        TagBox[
         SuperscriptBox["10", "3"], DisplayForm], TraditionalForm], {
       0.01, 0}, {}}, {-1.6094379124341005`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-1.2039728043259361`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.9162907318741553, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.6931471805599457, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.5108256237659909, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.3566749439387326, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.2231435513142104, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.10536051565782652`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6931471805599452, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.0986122886681096`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.3862943611198904`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6094379124341, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.7917594692280547`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.945910149055313, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.0794415416798353`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.197224577336219, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9957322735539913`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      4.2484952420493585`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.298317366548037, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.703782474656202, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.991464547107983, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.396929655216145, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.551080335043405, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}}, {{-2.3025850929940455`, 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {0., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {2.302585092994046, 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {4.605170185988092, 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {6.907755278982137, 
       FormBox["\"\"", TraditionalForm], {
       0.01, 0}, {}}, {-1.6094379124341005`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-1.2039728043259361`, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.9162907318741553, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.6931471805599457, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.5108256237659909, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.3566749439387326, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.2231435513142104, 
       FormBox["\"\"", TraditionalForm], {
       0.005, 0}, {}}, {-0.10536051565782652`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6931471805599452, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.0986122886681096`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.3862943611198904`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6094379124341, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      1.7917594692280547`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.945910149055313, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.0794415416798353`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.197224577336219, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      2.9957322735539913`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      3.4011973816621555`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      3.6888794541139363`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.912023005428146, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.0943445622221, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {
      4.2484952420493585`, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.382026634673881, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.499809670330265, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.298317366548037, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.703782474656202, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.991464547107983, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.214608098422191, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.396929655216145, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.551080335043405, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.684611727667927, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {6.802394763324311, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}}, {{{0., 
       FormBox["\"0\"", TraditionalForm], {0.01, 0}, {}}, {1., 
       FormBox["\"1\"", TraditionalForm], {0.01, 0}, {}}, {2., 
       FormBox["\"2\"", TraditionalForm], {0.01, 0}, {}}, {3., 
       FormBox["\"3\"", TraditionalForm], {0.01, 0}, {}}, {4., 
       FormBox["\"4\"", TraditionalForm], {0.01, 0}, {}}, {0.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6000000000000001, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{0., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {1., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {2., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {3., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {4., 
       FormBox["\"\"", TraditionalForm], {0.01, 0}, {}}, {0.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6000000000000001, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.2, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.4, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.6, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.8, 
       FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->216,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{-0.0001, 4}, {-1.1512925464970227`, 5.756462732485114}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 0}, {0, 0}},
  Ticks->{Automatic, Quiet[
     Charting`ScaledTicks[{Log, Exp}][#, #2, {6, 6}]]& }]], "Output",
 CellChangeTimes->{
  3.8074788856847687`*^9, {3.807478964607469*^9, 3.807479002414884*^9}},
 CellLabel->"Out[42]=",ExpressionUUID->"2439ba19-ee52-47b4-8682-e3c460dc246c"]
}, Open  ]],

Cell[TextData[{
 "\tAlternatively, if you are a SciDraw user, you might find  yourself \
wanting to include the output of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " in a SciDraw figure, via ",
 StyleBox["FigGraphics",
  FontFamily->"Courier New"],
 ", and then put logarithmic ticks on this figure.  (I generally just use the \
manual approach above, instead, and do not bother with ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 ".  But you may be a diehard ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " user...)\n\tSimilarly, if you are a more advanced Mathematica graphics \
programmer, you might find yourself wishing to use ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " or related ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions to generate graphics which you will then combine with other \
graphics to form a composite figure, and you then may wish to put logarithmic \
ticks on this figure.  It turns out that ",
 StyleBox["LogPlot",
  FontFamily->"Courier New"],
 " and its ilk do essentially what we described as the manual procedure \
above.  That is, they generate linear plots in which they have taken the \
logarithms of the coordinates.  But, they actually take the logarithm base ",
 StyleBox["e",
  FontSlant->"Italic"],
 ", rather than base 10.  (No matter that the ",
 StyleBox["ticks",
  FontSlant->"Italic"],
 " which they generate by default are base 10 log ticks...)  So, if you \
create ticks with ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 ", the coordinates describing where these ticks should be placed must be \
adjusted accordingly.  For instance, the tick for \[OpenCurlyDoubleQuote]10\
\[CloseCurlyDoubleQuote], instead of being located at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["log", "10"], TraditionalForm]],ExpressionUUID->
  "5b7e47d3-bbed-4a45-9970-8c128aff97c3"],
 "10=1 according to the procedure we described before, must now be at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["log", "e"], TraditionalForm]],ExpressionUUID->
  "e47a210e-533e-4e30-86e7-1b408270daf9"],
 "10\[TildeTilde]2.30259.  This rescaling of coordinates may be accomplished \
with the option setting ",
 StyleBox["LogPlot->E",
  FontFamily->"Courier New"],
 ".  ",
 StyleBox["Technical note:",
  FontSlant->"Italic"],
 " This option has the same effect as ",
 StyleBox["TickPostTransformation\[Rule](Log[10]*#&)",
  FontFamily->"Courier New"],
 " (see below).  "
}], "Text",
 CellChangeTimes->{{3.614199538286387*^9, 3.614199641146531*^9}, {
  3.6141996870765953`*^9, 3.614199690956601*^9}, {3.61419972583665*^9, 
  3.614200066197126*^9}, {3.614200225417349*^9, 3.614200286197434*^9}, {
  3.6142003400975094`*^9, 3.6142004628276815`*^9}, {3.614200808413165*^9, 
  3.614200825578189*^9}, {3.6142008659782457`*^9, 3.614200898658292*^9}, {
  3.6142010226134653`*^9, 3.6142012821438284`*^9}, {3.614201527019171*^9, 
  3.614201529854175*^9}, {3.6142015704592323`*^9, 3.614201652569347*^9}, {
  3.807479067923277*^9, 
  3.8074790788189077`*^9}},ExpressionUUID->"3659c5b3-59f6-4ecf-9d6d-\
4a6f237b9639"],

Cell["",
 PageBreakBelow->True,
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.6142016927244034`*^9},ExpressionUUID->"544992e0-510a-44e2-a4b6-\
566c16d25774"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Further control over tick placement and advanced customization\
\>", "Subsubsection",
 CellChangeTimes->{{3.52642425421875*^9, 
  3.526424261453125*^9}},ExpressionUUID->"8920c853-68fa-4910-a2c2-\
220e3c6e1b78"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"TmpMakeHelpBox", "[", 
    RowBox[{"\"\<OptionSummaryWideDescription\>\"", ",", "Contents___List"}], 
    "]"}], ":=", 
   RowBox[{"MakeColumnBox", "[", 
    RowBox[{"\"\<3ColumnBox\>\"", ",", "3", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"ColumnAlignments", "\[Rule]", 
        RowBox[{"{", "Left", "}"}]}], ",", 
       RowBox[{"RowLines", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"True", ",", "False"}], "}"}]}], ",", 
       RowBox[{"RowSpacings", "\[Rule]", "1.5"}], ",", 
       RowBox[{"ColumnWidths", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0.28", ",", "0.18", ",", "0.5"}], "}"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"StyleBox", "[", 
       RowBox[{"\"\<option name\>\"", ",", "\"\<SO10\>\""}], "]"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"StyleBox", "[", 
       RowBox[{"\"\<default value\>\"", ",", "\"\<SO10\>\""}], "]"}], "}"}], 
     ",", 
     RowBox[{"{", "\"\<\>\"", "}"}], ",", "\[IndentingNewLine]", "Contents"}],
     "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TmpMakeHelpBox", "[", 
   RowBox[{
   "\"\<OptionSummaryWideDescription\>\"", ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickLabelFunction\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<Automatic\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Function used to generate major tick labels (first argument is the \
numerical coordinate, second argument is the \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<LinTicks\>\"", "]"}], ",", 
      "\"\< default formatted label); \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<Automatic\>\"", "]"}], ",", 
      "\"\< gives the default label\>\""}], "}"}], ",", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickPreTransformation\>\"", "]"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<Identity\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Function to be applied to tick coordinates, before range tests \
and label generation\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickPostTransformation\>\"", "]"}], "}"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<Identity\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Function to be applied to tick coordinates, after range tests \
and label generation\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<MinorTickIndexTransformation\>\"", "]"}], 
     "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<Identity\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Function to be applied to minor tick indices (originally 1, 2, \
\[Ellipsis], \>\"", ",", 
      RowBox[{"textit", "[", "\"\<subdivs\>\"", "]"}], ",", 
      "\"\<-1) before minor tick coordinate is obtained by linear \
interpolation between major tick positions\>\""}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<MinorTickIndexRange\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<{1,Infinity}\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Limits drawing of minor ticks to those with indices (before \
tranformation) in given range\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<MinorTickLabelStyle\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<None\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", "\"\<Text style for minor tick labels\>\"", "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{"{", "\"\<Advanced customization options.\>\"", "}"}], "]"}], 
  ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.807481689033648*^9, 3.807481721474608*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"4a88e9a8-a16e-4b54-abeb-6e437415189d"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       StyleBox[
        RowBox[{"option", " ", "name"}], "SO10"], 
       StyleBox[
        RowBox[{"default", " ", "value"}], "SO10"], ""},
      {
       StyleBox["TickLabelFunction",
        FontFamily->"Courier"], 
       StyleBox["Automatic",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Function", " ", "used", " ", "to", " ", "generate", " ", "major", 
         " ", "tick", " ", "labels", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
           "first", " ", "argument", " ", "is", " ", "the", " ", "numerical", 
            " ", "coordinate"}], ",", " ", 
           RowBox[{
           "second", " ", "argument", " ", "is", " ", "the", " "}]}]}]}], 
        StyleBox["LinTicks",
         FontFamily->"Courier"], 
        RowBox[{
         RowBox[{
          RowBox[{" ", 
           RowBox[{"default", " ", "formatted", " ", "label"}], ")"}], ";"}], 
         " "}], 
        StyleBox["Automatic",
         FontFamily->"Courier"], 
        RowBox[{" ", 
         RowBox[{"gives", " ", "the", " ", "default", " ", "label"}]}]}]},
      {
       StyleBox["TickPreTransformation",
        FontFamily->"Courier"], 
       StyleBox["Identity",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Function", " ", "to", " ", "be", " ", "applied", " ", "to", " ", 
         "tick", " ", "coordinates"}], ",", " ", 
        RowBox[{
        "before", " ", "range", " ", "tests", " ", "and", " ", "label", " ", 
         "generation"}]}]},
      {
       StyleBox["TickPostTransformation",
        FontFamily->"Courier"], 
       StyleBox["Identity",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Function", " ", "to", " ", "be", " ", "applied", " ", "to", " ", 
         "tick", " ", "coordinates"}], ",", " ", 
        RowBox[{
        "after", " ", "range", " ", "tests", " ", "and", " ", "label", " ", 
         "generation"}]}]},
      {
       StyleBox["MinorTickIndexTransformation",
        FontFamily->"Courier"], 
       StyleBox["Identity",
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Function", " ", "to", " ", "be", " ", "applied", " ", "to", " ", 
         "minor", " ", "tick", " ", "indices", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"originally", " ", "1"}], ",", " ", "2", ",", " ", 
           "\[Ellipsis]", ",", " "}]}]}], 
        StyleBox["subdivs",
         FontSlant->"Italic"], 
        RowBox[{
         RowBox[{
          RowBox[{"-", "1"}], ")"}], " ", "before", " ", "minor", " ", "tick",
          " ", "coordinate", " ", "is", " ", "obtained", " ", "by", " ", 
         "linear", " ", "interpolation", " ", "between", " ", "major", " ", 
         "tick", " ", "positions"}]}]},
      {
       StyleBox["MinorTickIndexRange",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"{", 
         RowBox[{"1", ",", "Infinity"}], "}"}],
        FontFamily->"Courier"], 
       RowBox[{
       "Limits", " ", "drawing", " ", "of", " ", "minor", " ", "ticks", " ", 
        "to", " ", "those", " ", "with", " ", "indices", " ", 
        RowBox[{"(", 
         RowBox[{"before", " ", "tranformation"}], ")"}], " ", "in", " ", 
        "given", " ", "range"}]},
      {
       StyleBox["MinorTickLabelStyle",
        FontFamily->"Courier"], 
       StyleBox["None",
        FontFamily->"Courier"], 
       RowBox[{
       "Text", " ", "style", " ", "for", " ", "minor", " ", "tick", " ", 
        "labels"}]}
     }]], "3ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "Rows" -> {False, True, {False}, False}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.28], 
       Scaled[0.18], {
        Scaled[0.5]}}, "Rows" -> {{1.}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.807481724738158*^9},ExpressionUUID->"b3766806-03f7-4dbc-87b7-\
6623e6783430"],

Cell["Advanced customization options.", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.807481724759701*^9},ExpressionUUID->"39ea5de2-13c7-4301-8c7d-\
49316a84a29c"],

Cell[TextData[{
 "\t",
 StyleBox["LinTicks",
  FontFamily->"Courier New"],
 " accepts several options for advanced customization, allowing fully \
customizable labels and general nonlinear axis scales.  The option ",
 StyleBox["TickLabelFunction",
  FontFamily->"Courier New"],
 " is used to specify the function to be used to construct tick labels (see \
the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " documentation for ",
 StyleBox["Function",
  FontFamily->"Courier New"],
 " for information on defining functions).  The label function is given as \
arguments both the raw numerical tick coordinate and the ",
 StyleBox["LinTicks",
  FontFamily->"Courier New"],
 " default formatted label, so it can work with whichever is more convenient. \
 The label function may be used for simple tasks, such as attaching a prefix \
or suffix to the usual default label, or for more sophisticated formatting.  \
In the following example, tick values are formatted as rational multiples of \
\[Pi]."
}], "Text",ExpressionUUID->"09015af1-5a4f-42de-847d-43100ca31527"],

Cell["\<\
LinTicks[0,2*Pi,Pi/2,4,TickLabelFunction\[Rule](Rationalize[#/Pi]*Pi&)]\
\>", "Program",ExpressionUUID->"6e1e4227-e049-45cc-bee2-5fdab8797e90"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Scheme", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"RawGraphics", "[", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"Sin", "[", "x", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "0", ",", 
          RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
        RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"SchemeLine", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"2", "*", "Pi"}], ",", "0"}], "}"}]}], "}"}], "]"}]}], 
    "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"2", "*", "Pi"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.1"}], ",", "1.1"}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"LinTicks", "[", 
       RowBox[{"0", ",", 
        RowBox[{"2", "*", "Pi"}], ",", 
        RowBox[{"Pi", "/", "2"}], ",", "4", ",", 
        RowBox[{"TickLabelFunction", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"Rationalize", "[", 
             RowBox[{"#", "/", "Pi"}], "]"}], "*", "Pi"}], "&"}], ")"}]}]}], 
       "]"}], ",", 
      RowBox[{"LinTicks", "[", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2", ",", "1", ",", "5"}], "]"}], ",", 
      "None", ",", "None"}], "}"}]}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.52642283659375*^9, 3.5264228373125*^9}, 
   3.52642288984375*^9},
 CellLabel->
  "In[176]:=",ExpressionUUID->"cd059bee-d1fc-436f-8853-bbba49b6e7a7"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], {}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVl3k4lN8bxq1ZEjPvWJOifSWltOA5lUSklGgRmrSQEC1IijYk2VJkS4Xy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      "]]}}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], 
    LineBox[{{1.0842021724855044`*^-19, -2.220446049250313*^-16}, {
     6.283185307179586, -2.220446049250313*^-16}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->False,
  Background->None,
  BaseStyle->{
   FontFamily -> "Times", FontSize -> 12, FontSlant -> "Plain", FontTracking -> 
    "Plain", FontWeight -> "Plain", FontColor -> GrayLevel[0], FontOpacity -> 
    1, ShowAutoStyles -> False, SingleLetterItalics -> False},
  DisplayFunction->Identity,
  Frame->True,
  FrameLabel->{None, None, None, None},
  FrameStyle->Directive[{
     GrayLevel[0], 
     Opacity[1], 
     CapForm[None], 
     AbsoluteThickness[1], 
     AbsoluteDashing[{}]}],
  FrameTicks->{{{0., 
      FormBox["0", TraditionalForm], {0.01, 0}, {}}, {1.5707963267948966`, 
      FormBox[
       FractionBox["\[Pi]", "2"], TraditionalForm], {0.01, 0}, {}}, {
     3.141592653589793, 
      FormBox["\[Pi]", TraditionalForm], {0.01, 0}, {}}, {4.71238898038469, 
      FormBox[
       FractionBox[
        RowBox[{"3", " ", "\[Pi]"}], "2"], TraditionalForm], {0.01, 0}, {}}, {
     6.283185307179586, 
      FormBox[
       RowBox[{"2", " ", "\[Pi]"}], TraditionalForm], {0.01, 0}, {}}, {
     0.39269908169872414`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.7853981633974483, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.1780972450961724`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.9634954084936207`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.356194490192345, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {2.748893571891069, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.5342917352885173`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {3.9269908169872414`, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {4.319689898685965, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.105088062083414, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.497787143782138, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {5.890486225480862, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, {{-2., 
      FormBox["\"-2\"", TraditionalForm], {0.01, 0}, {}}, {-1., 
      FormBox["\"-1\"", TraditionalForm], {0.01, 0}, {}}, {0., 
      FormBox["\"0\"", TraditionalForm], {0.01, 0}, {}}, {1., 
      FormBox["\"1\"", TraditionalForm], {0.01, 0}, {}}, {2., 
      FormBox["\"2\"", TraditionalForm], {0.01, 0}, {}}, {-1.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-1.6, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-1.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-1.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.6, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {-0.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.6, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {0.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.2, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.4, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.6, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}, {1.8, 
      FormBox["\"\"", TraditionalForm], {0.005, 0}, {}}}, None, None},
  ImageSize->NCache[{288, 288/GoldenRatio}, {288, 177.9937887599697}],
  PlotRange->{{-0.0006283185307179586, 
   6.283813625710304}, {-1.1002200000000002`, 1.1002200000000002`}},
  Ticks->None]], "Output",
 CellChangeTimes->{3.526422839546875*^9, 3.52642289253125*^9},
 CellLabel->
  "Out[176]=",ExpressionUUID->"dadc26f3-0d58-4334-8cb1-3ca875042c9a"]
}, Open  ]],

Cell[TextData[{
 "Nonlinear axes are constructed using the coordinate transformation \
functions.  For instance, the ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " function provided by the CustomTicks package is actually implemented as a \
special case of ",
 StyleBox["LinTicks",
  FontFamily->"Courier New"],
 ", with transformed minor tick positions.  A very simplified implementation \
of ",
 StyleBox["LogTicks",
  FontFamily->"Courier New"],
 " (base 10 logarithm only) is given below for illustration."
}], "Text",
 CellChangeTimes->{{3.6142026695450544`*^9, 3.6142026791846056`*^9}, 
   3.614202709320699*^9},ExpressionUUID->"ec84cf47-19bf-4bfd-9ea0-\
b3c7aeb0d8fc"],

Cell["\<\
Log10Ticks[p1_Integer,p2_Integer,Opts___?OptionQ]:=LinTicks[
\t  p1,p2,1,9,
      TickLabelFunction\[Rule](DisplayForm[SuperscriptBox[10,IntegerPart[#]]]&\
),
      MinorTickIndexTransformation\[Rule](Log10[#+1]*9&),
      Opts
      ];\
\>", "Program",
 CellChangeTimes->{
  3.6142026012871504`*^9},ExpressionUUID->"ac2c08e4-192a-474c-8112-\
73dbcf127057"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<SymbolSummary\>\"", ",", "\[IndentingNewLine]", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<LinTicks[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<majorticklist\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<minorticklist\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Produces major and minor ticks at the specified coordinate \
values\>\"", "}"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{
   "{", "\"\<Form of tick specification function for ticks at arbitrary \
locations.\>\"", "}"}], "]"}], ";"}], "\[IndentingNewLine]"}], "Input",
 CellOpen->False,
 Hyphenation->False,
 CellLabel->"In[12]:=",ExpressionUUID->"e9e830b4-0185-4976-a1f3-7d6cd4fee88c"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       RowBox[{
        StyleBox[
         RowBox[{"LinTicks", "["}],
         FontFamily->"Courier"], 
        StyleBox["majorticklist",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["minorticklist",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
       "Produces", " ", "major", " ", "and", " ", "minor", " ", "ticks", " ", 
        "at", " ", "the", " ", "specified", " ", "coordinate", " ", "values"}]}
     }]], "2ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.31], {
        Scaled[0.65]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->
  True,ExpressionUUID->"65983aec-2ad5-48e7-8bfb-b02c999b1a17"],

Cell["\<\
Form of tick specification function for ticks at arbitrary locations.\
\>", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->
  True,ExpressionUUID->"76d78e83-8902-4c20-bef8-e0a43070179d"],

Cell[TextData[{
 "\tTicks may be placed at arbitrary coordinate locations by using the most \
flexible form of ",
 StyleBox["LinTicks",
  FontFamily->"Courier New"],
 ", in which all major and minor tick coordinates are specified explicitly in \
two lists.  All the usual coordinate-transformation and customization options \
described above (except ",
 StyleBox["MinorTickIndexRange",
  FontFamily->"Courier New"],
 ") are still applicable."
}], "Text",ExpressionUUID->"333f0140-6f37-4137-8b82-2e1fdd2cbd9f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Scheme", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"CodeOpts", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"FontFamily", "\[Rule]", "\"\<Courier\>\""}], ",", 
        RowBox[{"FontSize", "\[Rule]", "10"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"SetOptions", "[", 
      RowBox[{"ManualLabel", ",", 
       RowBox[{"Offset", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"+", "1"}]}], "}"}]}]}], "]"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"SchemeAxis", "[", 
      RowBox[{"Bottom", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "6.8"}], "}"}], ",", "0", ",", 
       RowBox[{"Ticks", "\[Rule]", 
        RowBox[{"LinTicks", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"0", ",", "1", ",", "2", ",", "3", ",", "5"}], "}"}], ",", 
          RowBox[{"Range", "[", 
           RowBox[{"0.1", ",", "0.9", ",", "0.1"}], "]"}], ",", 
          RowBox[{"MajorTickLength", "\[Rule]", 
           RowBox[{"4", "*", "0.00625"}]}], " ", ",", 
          RowBox[{"MinorTickLength", "\[Rule]", 
           RowBox[{"4", "*", "0.00375"}]}]}], "]"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", 
         RowBox[{
          RowBox[{"-", "0.2"}], "-", "0.3"}]}], "}"}], ",", 
       RowBox[{"StackText", "[", 
        RowBox[{"Center", ",", "0.5", ",", 
         RowBox[{"{", "\"\<Manual choice of tick coordinates\>\"", "}"}]}], 
        "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ManualLabel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"3", ",", 
         RowBox[{
          RowBox[{"-", "0.2"}], "-", "0.8"}]}], "}"}], ",", 
       "\"\<LinTicks[{0,1,2,3,5},Range[0.1,0.9,0.1]]\>\"", ",", "CodeOpts"}], 
      "]"}], ","}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.5"}], ",", "7.5"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.5"}], ",", "0.5"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"72", "*", 
     RowBox[{"{", 
      RowBox[{"5", ",", "1"}], "}"}]}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{3.516134924765625*^9},
 CellLabel->"In[6]:=",ExpressionUUID->"9c9b4904-237e-45e8-ba5f-60b1ac3a5e1d"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{2.220446049250313*^-16, 0.}, {6.8, 0.}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], LineBox[{{6.64997, 0.08335000000000004}, {6.800000000000001, 0.}, {
     6.64997, -0.08335000000000004}}]}, 
   {GrayLevel[0], AbsoluteThickness[1], Opacity[1], Dashing[{}], CapForm[
    None], {LineBox[{{2.220446049250313*^-16, 0.15003}, {
      2.220446049250313*^-16, 0.}}], 
     LineBox[{{1.0000000000000002`, 0.15003}, {1.0000000000000002`, 0.}}], 
     LineBox[{{2., 0.15003}, {2., 0.}}], LineBox[{{3., 0.15003}, {3., 0.}}], 
     LineBox[{{5., 0.15003}, {5., 0.}}], 
     LineBox[{{0.10000000000000023`, 0.09001799999999999}, {
      0.10000000000000023`, 0.}}], 
     LineBox[{{0.20000000000000023`, 0.09001799999999999}, {
      0.20000000000000023`, 0.}}], 
     LineBox[{{0.30000000000000027`, 0.09001799999999999}, {
      0.30000000000000027`, 0.}}], 
     LineBox[{{0.40000000000000024`, 0.09001799999999999}, {
      0.40000000000000024`, 0.}}], 
     LineBox[{{0.5000000000000002, 0.09001799999999999}, {0.5000000000000002, 
      0.}}], LineBox[{{0.6000000000000003, 0.09001799999999999}, {
      0.6000000000000003, 0.}}], 
     LineBox[{{0.7000000000000003, 0.09001799999999999}, {0.7000000000000003, 
      0.}}], LineBox[{{0.8000000000000003, 0.09001799999999999}, {
      0.8000000000000003, 0.}}], 
     LineBox[{{0.9000000000000002, 0.09001799999999999}, {0.9000000000000002, 
      0.}}]}, InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"0\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2.220446049250313*^-16, -0.013891666666666665}, {0, 1}, 
     Automatic, {1, 0}], InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"1\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {1.0000000000000002, -0.013891666666666665}, {0, 1}, 
     Automatic, {1, 0}], InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"2\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {2., -0.013891666666666665}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"3\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3., -0.013891666666666665}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"5\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {5., -0.013891666666666665}, {0, 1}, Automatic, {1, 0}], 
    InsetBox[
     TagBox[
      StyleBox[
       TagBox[GridBox[{
          {
           RowBox[{
           "Manual", " ", "choice", " ", "of", " ", "tick", " ", 
            "coordinates"}]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.5599999999999999]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{
              Offset[0.2]}}, "RowsIndexed" -> {}}],
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Times",
       FontSize->12,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3., -0.5}, {0, 1}, Automatic, {1, 0}], InsetBox[
     TagBox[
      StyleBox[
       TagBox["\<\"LinTicks[{0,1,2,3,5},Range[0.1,0.9,0.1]]\"\>",
        DisplayForm],
       StripOnInput->False,
       ShowAutoStyles->False,
       SingleLetterItalics->False,
       FontFamily->"Courier",
       FontSize->10,
       FontWeight->"Plain",
       FontSlant->"Plain",
       FontTracking->"Plain",
       FontColor->GrayLevel[0],
       FontOpacity->1],
      DisplayForm], {3., -1.}, {0, 1}, Automatic, {1, 0}]}},
  AspectRatio->NCache[
    Rational[1, 5], 0.2],
  Axes->False,
  Background->None,
  BaseStyle->{
   FontFamily -> "Times", FontSize -> 12, FontSlant -> "Plain", FontTracking -> 
    "Plain", FontWeight -> "Plain", FontColor -> GrayLevel[0], FontOpacity -> 
    1, ShowAutoStyles -> False, SingleLetterItalics -> False},
  DisplayFunction->Identity,
  Frame->False,
  FrameLabel->{None, None, None, None},
  FrameStyle->Directive[{
     GrayLevel[0], 
     Opacity[1], 
     CapForm[None], 
     AbsoluteThickness[1], 
     AbsoluteDashing[{}]}],
  FrameTicks->None,
  ImageSize->{360, 72},
  PlotRange->{{-1.5009, 7.5009}, {-1.5002, 0.5002}},
  Ticks->None]], "Output",
 CellChangeTimes->{3.51613492528125*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"cc2487d8-a672-4027-82d8-8c9a398c6de9"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{"\"\<OptionSummaryWideDescription\>\"", ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<ExtraTicks\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<{}\>\"", "]"}], "}"}], ",", 
    RowBox[{
    "{", "\"\<Additional coordinate values at which to insert tick marks\>\"",
      "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickTest\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<(True&)\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Logical test  to be applied to coordinate values, to select the \
coordinates at which tick marks are displayed (provides further control \
beyond the simple range test provided by \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<TickRange\>\"", "]"}], ",", 
      "\"\< above)\>\""}], "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<TickLabelTest\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"texttt", "[", "\"\<(True&)\>\"", "]"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Logical test to be applied to coordinate values, to select the \
coordinates at which tick labels are displayed (provides further control \
beyond the simple range test provided by \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<TickLabelRange\>\"", "]"}], ",", 
      "\"\< above)\>\""}], "}"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{
   "{", "\"\<Further options controlling the placement of tick marks and \
labels.\>\"", "}"}], "]"}], ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.52642427871875*^9, 3.526424284765625*^9}},
 CellLabel->
  "In[244]:=",ExpressionUUID->"2e9bf58c-dfed-40ec-9ae5-ec25383b91d6"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       StyleBox[
        RowBox[{"option", " ", "name"}], "SO10"], 
       StyleBox[
        RowBox[{"default", " ", "value"}], "SO10"], ""},
      {
       StyleBox["ExtraTicks",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"{", "}"}],
        FontFamily->"Courier"], 
       RowBox[{
       "Additional", " ", "coordinate", " ", "values", " ", "at", " ", 
        "which", " ", "to", " ", "insert", " ", "tick", " ", "marks"}]},
      {
       StyleBox["TickTest",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"(", 
         RowBox[{"True", "&"}], ")"}],
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Logical", " ", "test", "  ", "to", " ", "be", " ", "applied", " ", 
         "to", " ", "coordinate", " ", "values"}], ",", " ", 
        RowBox[{
        "to", " ", "select", " ", "the", " ", "coordinates", " ", "at", " ", 
         "which", " ", "tick", " ", "marks", " ", "are", " ", "displayed", 
         " ", 
         RowBox[{"(", 
          RowBox[{
          "provides", " ", "further", " ", "control", " ", "beyond", " ", 
           "the", " ", "simple", " ", "range", " ", "test", " ", "provided", 
           " ", "by", " ", 
           StyleBox["TickRange",
            FontFamily->"Courier"], " ", "above"}], ")"}]}]}]},
      {
       StyleBox["TickLabelTest",
        FontFamily->"Courier"], 
       StyleBox[
        RowBox[{"(", 
         RowBox[{"True", "&"}], ")"}],
        FontFamily->"Courier"], 
       RowBox[{
        RowBox[{
        "Logical", " ", "test", " ", "to", " ", "be", " ", "applied", " ", 
         "to", " ", "coordinate", " ", "values"}], ",", " ", 
        RowBox[{
        "to", " ", "select", " ", "the", " ", "coordinates", " ", "at", " ", 
         "which", " ", "tick", " ", "labels", " ", "are", " ", "displayed", 
         " ", 
         RowBox[{"(", 
          RowBox[{
          "provides", " ", "further", " ", "control", " ", "beyond", " ", 
           "the", " ", "simple", " ", "range", " ", "test", " ", "provided", 
           " ", "by", " ", 
           StyleBox["TickLabelRange",
            FontFamily->"Courier"], " ", "above"}], ")"}]}]}]}
     }]], "3ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.23], 
       Scaled[0.23], {
        Scaled[0.5]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.526424285125*^9},ExpressionUUID->"a0be9eb5-3411-4d86-b285-91900fbbe1d3"],

Cell["\<\
Further options controlling the placement of tick marks and labels.\
\>", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.5264242851875*^9},ExpressionUUID->"201ec902-20eb-4cba-a081-8b19c81e7056"],

Cell["\<\
\tOr, even without taking complete manual control of the choice of tick \
positions, some further control over tick placement is provided through the \
options above.\
\>", "Text",
 CellChangeTimes->{{3.526424696859375*^9, 
  3.5264247428125*^9}},ExpressionUUID->"34f7ba2c-a10c-488a-9309-e5fbcd898aab"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tick mark programming utilities", "Subsubsection",ExpressionUUID->"f4fc7c6e-d47f-4f15-a289-d6a84d7ed436"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<SymbolSummary\>\"", ",", "\[IndentingNewLine]", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<LimitTickRange[{\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x1\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x2\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<},\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<ticks\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Selects those tick mark with coordinates in the range \
specified; approximate equality testing is used to avoid dropping ticks at \
the ends of the interval due to roundoff; ticks must be specifies as lists \
rather than bare numbers\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<TransformTicks[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<coordfcn\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<lengthfcn\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<ticks\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Applies the specified transformation functions to the tick \
coordinates and tick lengths, respectively; ticks must be specified with an \
explicit pair of in and out lengths\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<StripTickLabels[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<ticks\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Removes any text labels from ticks; ticks must be specified as \
lists rather than bare numbers\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<AugmentTicks[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<labelfcn\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,{\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<l1\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<l2\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<},\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<stylelist\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<ticks\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
    "{", "\"\<Upgrades all tick specifications to full specifications, \
complete with labels, lengths into and out of the frame (default 0 for out), \
and style directives\>\"", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<AugmentAxisTickOptions[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<numaxes\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<tickoptions\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Given a list of tick options (themselves lists of tick \
specifications) for several axes, replaces any \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<None\>\"", "]"}], ",", 
      "\"\< entries with null lists and appends additional null lists as \
needed to make \>\"", ",", 
      RowBox[{"textit", "[", "\"\<numaxes\>\"", "]"}], ",", 
      "\"\< entries; a value \>\"", ",", 
      RowBox[{"texttt", "[", "\"\<None\>\"", "]"}], ",", "\"\< for \>\"", ",", 
      RowBox[{"textit", "[", "\"\<tickoptions\>\"", "]"}], ",", 
      "\"\< is replaced by a list of null lists\>\""}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<TickQ[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<Tests whether or not \>\"", ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      "\"\< is a valid tick mark specificiation\>\""}], "}"}], ",", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<TickListQ[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<Tests whether or not \>\"", ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      "\"\< is a list of valid tick mark specificiations\>\""}], "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{"{", "\"\<Tick manipulation utilities.\>\"", "}"}], "]"}], 
  ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{3.4247279345*^9},
 Hyphenation->False,
 CellLabel->"In[52]:=",ExpressionUUID->"79d3375b-1c76-4dbf-98b1-0e415c9958ec"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       RowBox[{
        StyleBox[
         RowBox[{"LimitTickRange", "[", "{"}],
         FontFamily->"Courier"], 
        StyleBox["x1",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["x2",
         FontSlant->"Italic"], 
        StyleBox[
         RowBox[{"}", ","}],
         FontFamily->"Courier"], 
        StyleBox["ticks",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Selects", " ", "those", " ", "tick", " ", "mark", " ", "with", " ", 
         "coordinates", " ", "in", " ", "the", " ", "range", " ", 
         "specified"}], ";", " ", 
        RowBox[{
        "approximate", " ", "equality", " ", "testing", " ", "is", " ", 
         "used", " ", "to", " ", "avoid", " ", "dropping", " ", "ticks", " ", 
         "at", " ", "the", " ", "ends", " ", "of", " ", "the", " ", 
         "interval", " ", "due", " ", "to", " ", "roundoff"}], ";", " ", 
        RowBox[{
        "ticks", " ", "must", " ", "be", " ", "specifies", " ", "as", " ", 
         "lists", " ", "rather", " ", "than", " ", "bare", " ", "numbers"}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"TransformTicks", "["}],
         FontFamily->"Courier"], 
        StyleBox["coordfcn",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["lengthfcn",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["ticks",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Applies", " ", "the", " ", "specified", " ", "transformation", " ", 
         "functions", " ", "to", " ", "the", " ", "tick", " ", "coordinates", 
         " ", "and", " ", "tick", " ", "lengths"}], ",", " ", 
        RowBox[{"respectively", ";", " ", 
         RowBox[{
         "ticks", " ", "must", " ", "be", " ", "specified", " ", "with", " ", 
          "an", " ", "explicit", " ", "pair", " ", "of", " ", "in", " ", 
          "and", " ", "out", " ", "lengths"}]}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"StripTickLabels", "["}],
         FontFamily->"Courier"], 
        StyleBox["ticks",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Removes", " ", "any", " ", "text", " ", "labels", " ", "from", " ", 
         "ticks"}], ";", " ", 
        RowBox[{
        "ticks", " ", "must", " ", "be", " ", "specified", " ", "as", " ", 
         "lists", " ", "rather", " ", "than", " ", "bare", " ", "numbers"}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"AugmentTicks", "["}],
         FontFamily->"Courier"], 
        StyleBox["labelfcn",
         FontSlant->"Italic"], 
        StyleBox[
         RowBox[{",", "{"}],
         FontFamily->"Courier"], 
        StyleBox["l1",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["l2",
         FontSlant->"Italic"], 
        StyleBox[
         RowBox[{"}", ","}],
         FontFamily->"Courier"], 
        StyleBox["stylelist",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["ticks",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Upgrades", " ", "all", " ", "tick", " ", "specifications", " ", "to",
          " ", "full", " ", "specifications"}], ",", " ", 
        RowBox[{"complete", " ", "with", " ", "labels"}], ",", " ", 
        RowBox[{
        "lengths", " ", "into", " ", "and", " ", "out", " ", "of", " ", "the",
          " ", "frame", " ", 
         RowBox[{"(", 
          RowBox[{"default", " ", "0", " ", "for", " ", "out"}], ")"}]}], ",",
         " ", 
        RowBox[{"and", " ", "style", " ", "directives"}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"AugmentAxisTickOptions", "["}],
         FontFamily->"Courier"], 
        StyleBox["numaxes",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["tickoptions",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{
        "Given", " ", "a", " ", "list", " ", "of", " ", "tick", " ", 
         "options", " ", 
         RowBox[{"(", 
          RowBox[{
          "themselves", " ", "lists", " ", "of", " ", "tick", " ", 
           "specifications"}], ")"}], " ", "for", " ", "several", " ", 
         "axes"}], ",", " ", 
        RowBox[{
         RowBox[{"replaces", " ", "any", " ", 
          StyleBox["None",
           FontFamily->"Courier"], " ", "entries", " ", "with", " ", "null", 
          " ", "lists", " ", "and", " ", "appends", " ", "additional", " ", 
          "null", " ", "lists", " ", "as", " ", "needed", " ", "to", " ", 
          "make", " ", 
          StyleBox["numaxes",
           FontSlant->"Italic"], " ", "entries"}], ";", " ", 
         RowBox[{"a", " ", "value", " ", 
          StyleBox["None",
           FontFamily->"Courier"], " ", "for", " ", 
          StyleBox["tickoptions",
           FontSlant->"Italic"], " ", 
          RowBox[{
          "is", " ", "replaced", " ", "by", " ", "a", " ", "list", " ", "of", 
           " ", "null", " ", "lists"}]}]}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"TickQ", "["}],
         FontFamily->"Courier"], 
        StyleBox["x",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{"Tests", " ", "whether", " ", "or", " ", "not", " ", 
        StyleBox["x",
         FontSlant->"Italic"], " ", 
        RowBox[{
        "is", " ", "a", " ", "valid", " ", "tick", " ", "mark", " ", 
         "specificiation"}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"TickListQ", "["}],
         FontFamily->"Courier"], 
        StyleBox["x",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{"Tests", " ", "whether", " ", "or", " ", "not", " ", 
        StyleBox["x",
         FontSlant->"Italic"], " ", 
        RowBox[{
        "is", " ", "a", " ", "list", " ", "of", " ", "valid", " ", "tick", 
         " ", "mark", " ", "specificiations"}]}]}
     }]], "2ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.31], {
        Scaled[0.65]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->
  True,ExpressionUUID->"0d2583fe-8278-4b7b-be01-037ccb32f796"],

Cell["Tick manipulation utilities.", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->
  True,ExpressionUUID->"3e6805cb-ed62-4d88-9755-6b4577fd369e"],

Cell["\<\
\tSeveral utility functions for tick mark manipulation and testing are \
provided.  These are mainly intended for use in graphics programming rather \
than for direct use by someone wishing to specify tick marks.  They are used \
internally by the LevelScheme figure preparation system.\
\>", "Text",
 CellChangeTimes->{{3.424727971765625*^9, 
  3.42472797553125*^9}},ExpressionUUID->"e3f38d98-6fc0-42d7-8f78-\
8cf6f8a49b7d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<SymbolSummary\>\"", ",", "\[IndentingNewLine]", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<FractionDigits[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Returns the number of digits to the right of the point in the \
decimal representation of \>\"", ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}]}], "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{"{", "\"\<Decimal digit counting function.\>\"", "}"}], "]"}], 
  ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{3.4247279345*^9},
 Hyphenation->False,
 CellLabel->"In[52]:=",ExpressionUUID->"46d9ca16-b4a5-4754-a273-774f0af64f85"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       RowBox[{
        StyleBox[
         RowBox[{"FractionDigits", "["}],
         FontFamily->"Courier"], 
        StyleBox["x",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
       "Returns", " ", "the", " ", "number", " ", "of", " ", "digits", " ", 
        "to", " ", "the", " ", "right", " ", "of", " ", "the", " ", "point", 
        " ", "in", " ", "the", " ", "decimal", " ", "representation", " ", 
        "of", " ", 
        StyleBox["x",
         FontSlant->"Italic"]}]}
     }]], "2ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.31], {
        Scaled[0.65]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->
  True,ExpressionUUID->"52e462e2-07b7-4662-b60c-c300d6472f09"],

Cell["Decimal digit counting function.", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->
  True,ExpressionUUID->"7afa60f7-66fa-49be-aa05-97d20a6ab0ed"],

Cell[TextData[{
 "\t",
 StyleBox["FractionDigits",
  FontFamily->"Courier New"],
 " determines the number of digits to the right of the point in the decimal \
representation of a number.  It is of use in constructing fixed-point tick \
labels.  It will, naturally, return large values, determined by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox["Precision",
  FontFamily->"Courier New"],
 ", for some numbers,  such as non-terminating rationals.  It accepts the \
option ",
 StyleBox["FractionDigitsBase",
  FontFamily->"Courier New"],
 ", by default 10, for work with non-decimal representations.  Some examples \
follow:"
}], "Text",ExpressionUUID->"9a9aada2-cc31-4b14-b0a6-691394d7edca"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FractionDigits", "[", "100", "]"}], "\[IndentingNewLine]", 
 RowBox[{"FractionDigits", "[", "1.25", "]"}], "\[IndentingNewLine]", 
 RowBox[{"FractionDigits", "[", 
  RowBox[{"1", "/", "3"}], "]"}]}], "Input",
 CellLabel->
  "In[441]:=",ExpressionUUID->"a00d09ff-764f-4676-9b44-106de2f9f39f"],

Cell[BoxData["0"], "Output",
 CellLabel->
  "Out[441]=",ExpressionUUID->"cf0eff92-24ee-4968-baca-e02ab7da1168"],

Cell[BoxData["2"], "Output",
 CellLabel->
  "Out[442]=",ExpressionUUID->"73c94def-5c1b-485b-981b-57271d56220e"],

Cell[BoxData["17"], "Output",
 CellLabel->
  "Out[443]=",ExpressionUUID->"0a2aa511-c35c-4898-9ac3-505505f00e82"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MakeHelpBox", "[", 
   RowBox[{
   "\"\<SymbolSummary\>\"", ",", "\[IndentingNewLine]", "\[IndentingNewLine]",
     "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<FixedPointForm[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<r\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<Formats \>\"", ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      "\"\< as a fixed\[Dash]point number with \>\"", ",", " ", 
      RowBox[{"textit", "[", "\"\<r\>\"", "]"}], ",", 
      "\"\<digits to the right of the decimal point.\>\""}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"texttt", "[", "\"\<FixedPointForm[\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,{\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<l\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<,\>\"", "]"}], ",", 
      RowBox[{"textit", "[", "\"\<r\>\"", "]"}], ",", 
      RowBox[{"texttt", "[", "\"\<}]\>\"", "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"\"\<Formats \>\"", ",", 
      RowBox[{"textit", "[", "\"\<x\>\"", "]"}], ",", 
      "\"\< as a fixed\[Dash]point number with \>\"", ",", 
      RowBox[{"textit", "[", "\"\<l\>\"", "]"}], ",", 
      "\"\< digits (or spaces) to the left and \>\"", ",", " ", 
      RowBox[{"textit", "[", "\"\<r\>\"", "]"}], ",", 
      "\"\< digits to the right of the decimal point.\>\""}], "}"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}],
   ";"}], "\n", 
 RowBox[{
  RowBox[{"MakeCaptionBox", "[", 
   RowBox[{"{", "\"\<Decimal digit counting function.\>\"", "}"}], "]"}], 
  ";"}]}], "Input",
 CellOpen->False,
 CellChangeTimes->{
  3.4247279345*^9, {3.526423042921875*^9, 3.526423229609375*^9}, {
   3.526423265203125*^9, 3.52642326859375*^9}},
 Hyphenation->False,
 CellLabel->
  "In[183]:=",ExpressionUUID->"4e439ab6-a6bd-44d0-81ba-a702a5d16007"],

Cell[BoxData[
 FormBox[
  StyleBox[
   FrameBox[GridBox[{
      {
       RowBox[{
        StyleBox[
         RowBox[{"FixedPointForm", "["}],
         FontFamily->"Courier"], 
        StyleBox["x",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["r",
         FontSlant->"Italic"], 
        StyleBox["]",
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{"Formats", " ", 
         StyleBox["x",
          FontSlant->"Italic"], " ", 
         RowBox[{"as", " ", "a", " ", "fixed"}]}], "\[Dash]", 
        RowBox[{"point", " ", "number", " ", "with", " ", 
         StyleBox["r",
          FontSlant->"Italic"], 
         RowBox[{
         "digits", " ", "to", " ", "the", " ", "right", " ", "of", " ", "the",
           " ", "decimal", " ", 
          RowBox[{"point", "."}]}]}]}]},
      {
       RowBox[{
        StyleBox[
         RowBox[{"FixedPointForm", "["}],
         FontFamily->"Courier"], 
        StyleBox["x",
         FontSlant->"Italic"], 
        StyleBox[
         RowBox[{",", "{"}],
         FontFamily->"Courier"], 
        StyleBox["l",
         FontSlant->"Italic"], 
        StyleBox[",",
         FontFamily->"Courier"], 
        StyleBox["r",
         FontSlant->"Italic"], 
        StyleBox[
         RowBox[{"}", "]"}],
         FontFamily->"Courier"]}], 
       RowBox[{
        RowBox[{"Formats", " ", 
         StyleBox["x",
          FontSlant->"Italic"], " ", 
         RowBox[{"as", " ", "a", " ", "fixed"}]}], "\[Dash]", 
        RowBox[{"point", " ", "number", " ", "with", " ", 
         StyleBox["l",
          FontSlant->"Italic"], " ", "digits", " ", 
         RowBox[{"(", 
          RowBox[{"or", " ", "spaces"}], ")"}], " ", "to", " ", "the", " ", 
         "left", " ", "and", " ", 
         StyleBox["r",
          FontSlant->"Italic"], " ", 
         RowBox[{
         "digits", " ", "to", " ", "the", " ", "right", " ", "of", " ", "the",
           " ", "decimal", " ", 
          RowBox[{"point", "."}]}]}]}]}
     }]], "2ColumnBox",
   FontFamily->"Times",
   GridBoxOptions->{
   GridBoxAlignment->{
    "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
     "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
   GridBoxDividers->{
    "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{"Columns" -> {
       Scaled[0.31], {
        Scaled[0.65]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.5599999999999999]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.6]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}}], DisplayForm]], "Text",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.526423269171875*^9},ExpressionUUID->"0a2facfe-3b91-492e-b94c-\
43d4c47691b6"],

Cell["Decimal digit counting function.", "Caption",
 GeneratedCell->True,
 CellAutoOverwrite->True,
 CellChangeTimes->{
  3.526423269234375*^9},ExpressionUUID->"a27721a8-5d8e-4a92-a0a5-\
fa0e452f479e"],

Cell[TextData[{
 "\t",
 StyleBox["FixedPointForm",
  FontFamily->"Courier New"],
 " returns a string, consisting of the real number ",
 StyleBox["x",
  FontSlant->"Italic"],
 " formatted in fixed-point representation.  It is used internally by \
CustomTicks in constructing fixed-point tick labels, hence its inclusion in \
this package, but it may be used to format numbers in many other contexts as \
well.  Some examples follow:"
}], "Text",
 CellChangeTimes->{{3.526423302125*^9, 3.526423439546875*^9}, {
  3.526423782375*^9, 3.526423794421875*^9}, {3.526423832328125*^9, 
  3.526423881921875*^9}, {3.526424020953125*^9, 
  3.52642402596875*^9}},ExpressionUUID->"58fe7460-a42b-464e-9f4f-\
21c5e8e91bb6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{"Pi", "//", "N"}], ",", "5"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{"Pi", "//", "N"}], ",", "2"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{"Pi", "//", "N"}], ",", "0"}], "]"}]}], "Input",
 CellChangeTimes->{{3.52642368534375*^9, 3.526423733046875*^9}, {
  3.526423899515625*^9, 3.526423909328125*^9}},
 CellLabel->
  "In[219]:=",ExpressionUUID->"a7249185-988d-40bb-a787-28ec4b72d3d5"],

Cell[BoxData["\<\" 3.14159\"\>"], "Output",
 CellChangeTimes->{{3.526423902515625*^9, 3.52642390965625*^9}},
 CellLabel->
  "Out[219]=",ExpressionUUID->"75db34ba-bf11-4e4d-a0b6-17d8224abd08"],

Cell[BoxData["\<\" 3.14\"\>"], "Output",
 CellChangeTimes->{{3.526423902515625*^9, 3.526423909703125*^9}},
 CellLabel->
  "Out[220]=",ExpressionUUID->"d186671c-f0ab-4866-995e-682a1e8ab5b8"],

Cell[BoxData["\<\" 3\"\>"], "Output",
 CellChangeTimes->{{3.526423902515625*^9, 3.52642390975*^9}},
 CellLabel->
  "Out[221]=",ExpressionUUID->"18566d81-0f01-444e-908f-9ed8ef4cf92c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{"Pi", "//", "N"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"4", "*", "Pi"}], "//", "N"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.52642368534375*^9, 3.526423726625*^9}, 
   3.526423797734375*^9},
 CellLabel->
  "In[210]:=",ExpressionUUID->"29e895de-815a-4c7f-966f-5efee9433091"],

Cell[BoxData["\<\"  3.142\"\>"], "Output",
 CellChangeTimes->{{3.5264237163125*^9, 3.526423726875*^9}},
 CellLabel->
  "Out[210]=",ExpressionUUID->"bd9aecbb-4b49-49b7-93ba-6874a1b630c9"],

Cell[BoxData["\<\" 12.566\"\>"], "Output",
 CellChangeTimes->{{3.5264237163125*^9, 3.526423726921875*^9}},
 CellLabel->
  "Out[211]=",ExpressionUUID->"fb1400d7-0f9d-4f27-b1c8-dc123eab594a"]
}, Open  ]],

Cell[TextData[{
 StyleBox["FixedPointForm",
  FontFamily->"Courier New"],
 " accepts options ",
 StyleBox["NumberSigns",
  FontFamily->"Courier New"],
 ", ",
 StyleBox["SignPadding",
  FontFamily->"Courier New"],
 ", and ",
 StyleBox["NumberPoint",
  FontFamily->"Courier New"],
 ", which are defined much as for the usual built-in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " numerical formatting functions ",
 StyleBox["NumberForm",
  FontFamily->"Courier New"],
 ", ",
 StyleBox["etc.",
  FontSlant->"Italic"],
 "  (See the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " documentation for further information on their usage.)  By default, for \
positive numbers a blank padding space appears at left, where a minus sign \
would be for negative numbers, to improve alignment with negative numbers.  \
However, ",
 StyleBox["FixedPointForm",
  FontFamily->"Courier New"],
 " also accepts the special value ",
 StyleBox["NumberSigns\[Rule]Automatic",
  FontFamily->"Courier New"],
 ", which specifies that this space should be suppressed.  In general, this \
provides a better appearance for tick labels. "
}], "Text",
 CellChangeTimes->{{3.526423302125*^9, 3.526423439546875*^9}, {
  3.526423782375*^9, 3.526423794421875*^9}, {3.526423832328125*^9, 
  3.526423887578125*^9}, {3.52642392653125*^9, 3.52642395121875*^9}, {
  3.6141975712165823`*^9, 3.6141976286304817`*^9}, {3.614197706412218*^9, 
  3.6141977849895563`*^9}, {3.614197827312431*^9, 3.614197883347729*^9}, {
  3.6141982654392004`*^9, 
  3.614198297575257*^9}},ExpressionUUID->"3227fc29-b148-4bc1-91a9-\
75edbddbd20c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{"Pi", "//", "N"}], ",", "3"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "Pi"}], "//", "N"}], ",", "3"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"FixedPointForm", "[", 
  RowBox[{
   RowBox[{"Pi", "//", "N"}], ",", "3", ",", 
   RowBox[{"NumberSigns", "->", "Automatic"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.52642355246875*^9, 3.5264236769375*^9}},
 CellLabel->
  "In[214]:=",ExpressionUUID->"3b498a16-f41e-4c8a-8dca-c0b37d14e5df"],

Cell[BoxData["\<\" 3.142\"\>"], "Output",
 CellChangeTimes->{{3.526423559296875*^9, 3.526423614203125*^9}, {
   3.526423650859375*^9, 3.52642366528125*^9}, 3.526423736390625*^9},
 CellLabel->
  "Out[214]=",ExpressionUUID->"8a693d9c-b1c0-4e51-988e-f9190690d2dd"],

Cell[BoxData["\<\"-3.142\"\>"], "Output",
 CellChangeTimes->{{3.526423559296875*^9, 3.526423614203125*^9}, {
   3.526423650859375*^9, 3.52642366528125*^9}, 3.52642373640625*^9},
 CellLabel->
  "Out[215]=",ExpressionUUID->"b8e325cc-085f-4f14-9885-ada74da6d1c9"],

Cell[BoxData["\<\"3.142\"\>"], "Output",
 CellChangeTimes->{{3.526423559296875*^9, 3.526423614203125*^9}, {
   3.526423650859375*^9, 3.52642366528125*^9}, 3.526423736453125*^9},
 CellLabel->
  "Out[216]=",ExpressionUUID->"38cfa0c5-9daf-451a-bb07-9c77fa43cff7"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Technical notes:",
  FontSlant->"Italic"],
 " ",
 StyleBox["FixedPointForm",
  FontFamily->"Courier New"],
 " allows as many digits as necessary to the left of the decimal point, \
thereby avoiding the rounding problem associated with ",
 StyleBox["PaddedForm[",
  FontFamily->"Courier New"],
 StyleBox["x",
  FontSlant->"Italic"],
 StyleBox[",{",
  FontFamily->"Courier New"],
 StyleBox["n",
  FontSlant->"Italic"],
 StyleBox[",",
  FontFamily->"Courier New"],
 StyleBox["f",
  FontSlant->"Italic"],
 StyleBox["}]",
  FontFamily->"Courier New"],
 " when ",
 StyleBox["n",
  FontSlant->"Italic"],
 " is specified too small (",
 StyleBox["PaddedForm",
  FontFamily->"Courier New"],
 " zeros out some of the rightmost digits of the number).  It also suppresses \
any trailing decimal point when ",
 StyleBox["r",
  FontSlant->"Italic"],
 "=0."
}], "Text",
 CellChangeTimes->{{3.526423302125*^9, 3.526423470421875*^9}, {
   3.52642376296875*^9, 3.526423778953125*^9}, 
   3.5264239686875*^9},ExpressionUUID->"5e0a3223-55d4-4121-8df0-d16e1b3bdb9c"],

Cell["\[Copyright] Copyright 2020, Mark A. Caprio.", "Text",
 CellChangeTimes->{
  3.424727901109375*^9, {3.516135675765625*^9, 3.516135675953125*^9}, {
   3.5668384004564514`*^9, 3.5668384054664583`*^9}, {3.6141978905081415`*^9, 
   3.614197890617342*^9}, {3.666801222595255*^9, 3.6668012231568556`*^9}, {
   3.807479161897366*^9, 
   3.807479162034543*^9}},ExpressionUUID->"afcfb616-e12b-4107-a632-\
bcf3831552bb"]
}, Open  ]]
},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Brackets",
WindowToolbars->"RulerBar",
WindowSize->{1440., 774.75},
WindowMargins->{{0, Automatic}, {Automatic, 13.5}},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{"Printed", " ", "from", " ", "the", " ", 
        StyleBox["Mathematica", FontSlant -> "Italic"], " ", "Help", " ", 
        "Browser"}], "PageHeader"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}, {
   Cell[
    TextData[
     StyleBox[
      RowBox[{"CustomTicks", " ", "package"}], "PageHeader"]], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}},
PageFooters->{{None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{
       "\[Copyright]2003", " ", "M", ".", " ", "A", ".", " ", "Caprio"}], 
      "PageFooter"]], "Footer"], None}, {None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{"Version", " ", "2.1", ".1"}], "PageFooter"]], "Footer"], None}},
PageHeaderLines->{True, True},
PageFooterLines->{True, True},
PrintingOptions->{"FacingPages"->False,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->False,
"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{Automatic, Automatic},
"PostScriptOutputFile"->"/home/mcaprio/mathematica/CustomTicks/\
CustomTicksGuide.pdf"},
ShowSelection->True,
CellElementSpacings->{"ClosedCellHeight"->1},
ShowCellLabel->False,
LanguageCategory->None,
Magnification->1.5,
FrontEndVersion->"12.1 for Linux x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"HelpBrowser.nb",
ExpressionUUID->"bd37b63f-7a15-45b8-a95a-c8eafe685c1d"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1034, 21, 162, "Text",ExpressionUUID->"b9a012dc-af07-482b-bdc9-9fc3e04818b2"],
Cell[1582, 43, 934, 18, 14, "Text",ExpressionUUID->"06a94110-0c96-4d64-a2ae-97e3c532bfa3",
 CellOpen->False],
Cell[CellGroupData[{
Cell[2541, 65, 92, 0, 51, "Subsubsection",ExpressionUUID->"c05faaf6-6435-4d7b-9f90-d9033ebf040b"],
Cell[2636, 67, 727, 12, 104, "Text",ExpressionUUID->"4675df0d-1e1b-42c3-b297-afd05360a993"],
Cell[3366, 81, 745, 19, 59, "Text",ExpressionUUID->"ee043ea3-ae5f-4dea-8a2d-e5f82bc82b18"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4148, 105, 105, 0, 51, "Subsubsection",ExpressionUUID->"facd6d9a-fbbf-4645-b334-6101f29e104b"],
Cell[4256, 107, 560, 13, 57, "Text",ExpressionUUID->"12e832d3-63b0-4427-b963-7bf03a4ba156"],
Cell[4819, 122, 715, 18, 83, "Text",ExpressionUUID->"fc97c809-0d00-4e2a-b890-a5b8ddc05d0a"],
Cell[5537, 142, 11579, 258, 18, "Input",ExpressionUUID->"cfeddf36-ba9b-4a0f-94ce-aa8e5ff19a9b",
 CellOpen->False],
Cell[17119, 402, 2240, 71, 65, "Text",ExpressionUUID->"863de696-12ba-4143-a4c8-056f565b429d"],
Cell[19362, 475, 193, 4, 23, "Caption",ExpressionUUID->"166851b1-0c63-4796-8168-f88b9e059239"],
Cell[19558, 481, 2002, 59, 121, "Text",ExpressionUUID->"84997450-1f63-4ca2-bf6c-59a1d8190f6a"],
Cell[21563, 542, 247, 7, 23, "Caption",ExpressionUUID->"e03a5cec-7b0f-4286-bfad-2d1c85bc4552"],
Cell[21813, 551, 3466, 99, 271, "Text",ExpressionUUID->"02573b4c-b83e-4c31-aa60-05f7fcdf7ff9"],
Cell[25282, 652, 242, 7, 23, "Caption",ExpressionUUID->"3ef897e2-7e55-4581-865a-9bfd4ace3b28"],
Cell[25527, 661, 4895, 137, 405, "Text",ExpressionUUID->"1abbb6c7-97c5-42f5-b56b-e91893e0b104"],
Cell[30425, 800, 219, 5, 23, "Caption",ExpressionUUID->"c4f895f2-cc73-4efd-8e78-85d98f2c07a0"],
Cell[30647, 807, 2601, 75, 175, "Text",ExpressionUUID->"82773f31-ae87-48b4-84a1-87157e24525b"],
Cell[33251, 884, 281, 8, 23, "Caption",ExpressionUUID->"b5b8fed1-06bd-4f72-8149-c744f7dcf43e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33569, 897, 96, 0, 51, "Subsubsection",ExpressionUUID->"2392c945-8773-4315-aea5-9a4ce94214b5"],
Cell[33668, 899, 1181, 39, 85, "Text",ExpressionUUID->"7d5661fa-261e-4ff0-b070-9bbb831aafae"],
Cell[34852, 940, 1751, 39, 18, "Input",ExpressionUUID->"823756dc-8f23-4fc4-a6d9-3573edf11c59",
 CellOpen->False],
Cell[36606, 981, 2125, 68, 65, "Text",ExpressionUUID->"57149e5f-6044-4cae-8860-b6b4be377020"],
Cell[38734, 1051, 165, 3, 23, "Caption",ExpressionUUID->"9e18ec93-3d34-4aed-938b-1c009c7fa01e"],
Cell[38902, 1056, 1435, 45, 83, "Text",ExpressionUUID->"27c3f5a0-4c92-4ffa-92b3-ba4ebdc31235"],
Cell[CellGroupData[{
Cell[40362, 1105, 6617, 170, 1, "Input",ExpressionUUID->"49ccdae9-77f9-43e8-b0bd-1dc158eda0cc",
 CellOpen->False],
Cell[46982, 1277, 37921, 952, 393, "Output",ExpressionUUID->"c387d245-84fd-4fa0-a5c8-2b8c4ef916f8"]
}, Open  ]],
Cell[84918, 2232, 2362, 84, 213, "Text",ExpressionUUID->"0448b59a-6af4-495a-9024-8129f44cd4a2"],
Cell[87283, 2318, 722, 15, 231, "Program",ExpressionUUID->"93852e88-1ba5-4dc8-aa7c-0e6cac73295b"],
Cell[CellGroupData[{
Cell[88030, 2337, 1990, 51, 1, "Input",ExpressionUUID->"25e7dd5d-42f7-449b-b16d-5e955d9e1267",
 CellOpen->False],
Cell[90023, 2390, 14633, 287, 238, "Output",ExpressionUUID->"5798dee0-2756-4883-a39d-44b1b2406a15"]
}, Open  ]],
Cell[104671, 2680, 708, 16, 231, "Program",ExpressionUUID->"9b0b5418-90e0-48a9-8681-a1cb1eb5efe6"],
Cell[CellGroupData[{
Cell[105404, 2700, 1947, 53, 1, "Input",ExpressionUUID->"2138e373-7d51-4e3b-badd-04d3cf7197cb",
 CellOpen->False],
Cell[107354, 2755, 10706, 231, 223, "Output",ExpressionUUID->"a6234db5-a6aa-4a68-90bf-06ac54658b68"]
}, Open  ]],
Cell[118075, 2989, 576, 16, 58, "Text",ExpressionUUID->"db1d383d-255d-476d-bd0f-20283d14d3f3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[118688, 3010, 303, 9, 51, "Subsubsection",ExpressionUUID->"d9d549fe-4fca-4c3a-ad4b-8cc92abda2ad"],
Cell[118994, 3021, 620, 16, 58, "Text",ExpressionUUID->"2e42286e-0617-41f6-9561-5a7d2667345e"],
Cell[119617, 3039, 633, 13, 160, "Program",ExpressionUUID->"f3d1a483-73c5-4a3a-9a3d-3e27f7f2b130"],
Cell[CellGroupData[{
Cell[120275, 3056, 1601, 43, 1, "Input",ExpressionUUID->"3d87b9d9-ca82-4f93-bfe7-f425062a981f",
 CellOpen->False],
Cell[121879, 3101, 10167, 206, 224, "Output",ExpressionUUID->"4960cea2-a1b7-474d-b802-124774be77f5"]
}, Open  ]],
Cell[132061, 3310, 817, 18, 84, "Text",ExpressionUUID->"c1134898-a1b1-4978-8033-a8d13e2eb432"],
Cell[132881, 3330, 820, 17, 160, "Program",ExpressionUUID->"7367643d-969a-47c7-b818-a7e1b2d4863e"],
Cell[CellGroupData[{
Cell[133726, 3351, 1819, 47, 18, "Input",ExpressionUUID->"6738f218-2c40-4c4b-9079-52e3ec9d70d6",
 CellOpen->False],
Cell[135548, 3400, 14631, 287, 238, "Output",ExpressionUUID->"a2f5e506-44f9-44fb-bb42-ad0a9bc2617e"]
}, Open  ]],
Cell[150194, 3690, 361, 10, 35, "Text",ExpressionUUID->"10594554-f427-43fa-b156-65e5950fc2f5"],
Cell[150558, 3702, 714, 16, 160, "Program",ExpressionUUID->"5363ab65-490d-4d12-81cf-623c02e9cfc7"],
Cell[CellGroupData[{
Cell[151297, 3722, 1868, 49, 18, "Input",ExpressionUUID->"93f7f39f-8965-4617-88bf-fab829be37cb",
 CellOpen->False],
Cell[153168, 3773, 33221, 653, 191, "Output",ExpressionUUID->"d7609fb7-47fe-4ef4-81d9-ba15513bd96e"]
}, Open  ]],
Cell[186404, 4429, 1229, 29, 18, "Input",ExpressionUUID->"8258f662-6ecc-49fd-b088-5b9ef7776ef0",
 CellOpen->False],
Cell[187636, 4460, 1739, 47, 91, "Text",ExpressionUUID->"f8f1b1b1-d8bd-4559-89ec-546a2d8fb668"],
Cell[189378, 4509, 248, 9, 23, "Caption",ExpressionUUID->"0bfd5728-f775-4436-8b83-9d888501bef6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[189663, 4523, 226, 7, 51, "Subsubsection",ExpressionUUID->"2162b609-0e3d-46f6-800c-f79df05be618"],
Cell[189892, 4532, 1329, 38, 108, "Text",ExpressionUUID->"0fab764b-24b3-43c3-8868-11af346110a2"],
Cell[191224, 4572, 793, 17, 184, "Program",ExpressionUUID->"7f5bfd74-8f2e-419e-9ec2-11d3ea59b51f"],
Cell[CellGroupData[{
Cell[192042, 4593, 1828, 45, 18, "Input",ExpressionUUID->"fd4575c7-9ddf-4119-bf38-9c227a0ef3dc",
 CellOpen->False],
Cell[193873, 4640, 16128, 296, 238, "Output",ExpressionUUID->"2439ba19-ee52-47b4-8682-e3c460dc246c"]
}, Open  ]],
Cell[210016, 4939, 3160, 75, 287, "Text",ExpressionUUID->"3659c5b3-59f6-4ecf-9d6d-4a6f237b9639"],
Cell[213179, 5016, 183, 6, 34, InheritFromParent,ExpressionUUID->"544992e0-510a-44e2-a4b6-566c16d25774",
 PageBreakBelow->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[213399, 5027, 220, 5, 51, "Subsubsection",ExpressionUUID->"8920c853-68fa-4910-a2c2-220e3c6e1b78"],
Cell[213622, 5034, 4229, 99, 1, "Input",ExpressionUUID->"4a88e9a8-a16e-4b54-abeb-6e437415189d",
 CellOpen->False],
Cell[217854, 5135, 4332, 123, 387, "Text",ExpressionUUID->"b3766806-03f7-4dbc-87b7-6623e6783430"],
Cell[222189, 5260, 200, 5, 23, "Caption",ExpressionUUID->"39ea5de2-13c7-4301-8c7d-49316a84a29c"],
Cell[222392, 5267, 1068, 24, 131, "Text",ExpressionUUID->"09015af1-5a4f-42de-847d-43100ca31527"],
Cell[223463, 5293, 153, 2, 43, "Program",ExpressionUUID->"6e1e4227-e049-45cc-bee2-5fdab8797e90"],
Cell[CellGroupData[{
Cell[223641, 5299, 1984, 56, 1, "Input",ExpressionUUID->"cd059bee-d1fc-436f-8853-bbba49b6e7a7",
 CellOpen->False],
Cell[225628, 5357, 13029, 224, 281, "Output",ExpressionUUID->"dadc26f3-0d58-4334-8cb1-3ca875042c9a"]
}, Open  ]],
Cell[238672, 5584, 685, 17, 83, "Text",ExpressionUUID->"ec84cf47-19bf-4bfd-9ea0-b3c7aeb0d8fc"],
Cell[239360, 5603, 367, 11, 160, "Program",ExpressionUUID->"ac2c08e4-192a-474c-8112-73dbcf127057"],
Cell[239730, 5616, 1068, 25, 1, "Input",ExpressionUUID->"e9e830b4-0185-4976-a1f3-7d6cd4fee88c",
 CellOpen->False],
Cell[240801, 5643, 1474, 42, 37, "Text",ExpressionUUID->"65983aec-2ad5-48e7-8bfb-b02c999b1a17"],
Cell[242278, 5687, 202, 5, 23, "Caption",ExpressionUUID->"76d78e83-8902-4c20-bef8-e0a43070179d"],
Cell[242483, 5694, 509, 11, 83, "Text",ExpressionUUID->"333f0140-6f37-4137-8b82-2e1fdd2cbd9f"],
Cell[CellGroupData[{
Cell[243017, 5709, 2637, 69, 1, "Input",ExpressionUUID->"9c9b4904-237e-45e8-ba5f-60b1ac3a5e1d",
 CellOpen->False],
Cell[245657, 5780, 6124, 175, 123, "Output",ExpressionUUID->"cc2487d8-a672-4027-82d8-8c9a398c6de9"]
}, Open  ]],
Cell[251796, 5958, 1994, 44, 1, "Input",ExpressionUUID->"2e9bf58c-dfed-40ec-9ae5-ec25383b91d6",
 CellOpen->False],
Cell[253793, 6004, 3199, 86, 245, "Text",ExpressionUUID->"a0be9eb5-3411-4d86-b285-91900fbbe1d3"],
Cell[256995, 6092, 240, 6, 23, "Caption",ExpressionUUID->"201ec902-20eb-4cba-a081-8b19c81e7056"],
Cell[257238, 6100, 312, 6, 57, "Text",ExpressionUUID->"34f7ba2c-a10c-488a-9309-e5fbcd898aab"]
}, Open  ]],
Cell[CellGroupData[{
Cell[257587, 6111, 111, 0, 51, "Subsubsection",ExpressionUUID->"f4fc7c6e-d47f-4f15-a289-d6a84d7ed436"],
Cell[257701, 6113, 5510, 116, 1, "Input",ExpressionUUID->"79d3375b-1c76-4dbf-98b1-0e415c9958ec",
 CellOpen->False],
Cell[263214, 6231, 7392, 208, 365, "Text",ExpressionUUID->"0d2583fe-8278-4b7b-be01-037ccb32f796"],
Cell[270609, 6441, 153, 3, 23, "Caption",ExpressionUUID->"3e6805cb-ed62-4d88-9755-6b4577fd369e"],
Cell[270765, 6446, 435, 8, 57, "Text",ExpressionUUID->"e3f38d98-6fc0-42d7-8f78-8cf6f8a49b7d"],
Cell[271203, 6456, 993, 25, 1, "Input",ExpressionUUID->"46d9ca16-b4a5-4754-a273-774f0af64f85",
 CellOpen->False],
Cell[272199, 6483, 1493, 42, 37, "Text",ExpressionUUID->"52e462e2-07b7-4662-b60c-c300d6472f09"],
Cell[273695, 6527, 157, 3, 23, "Caption",ExpressionUUID->"7afa60f7-66fa-49be-aa05-97d20a6ab0ed"],
Cell[273855, 6532, 715, 18, 84, "Text",ExpressionUUID->"9a9aada2-cc31-4b14-b0a6-691394d7edca"],
Cell[CellGroupData[{
Cell[274595, 6554, 316, 6, 91, "Input",ExpressionUUID->"a00d09ff-764f-4676-9b44-106de2f9f39f"],
Cell[274914, 6562, 111, 2, 36, "Output",ExpressionUUID->"cf0eff92-24ee-4968-baca-e02ab7da1168"],
Cell[275028, 6566, 111, 2, 36, "Output",ExpressionUUID->"73c94def-5c1b-485b-981b-57271d56220e"],
Cell[275142, 6570, 112, 2, 36, "Output",ExpressionUUID->"0a2aa511-c35c-4898-9ac3-505505f00e82"]
}, Open  ]],
Cell[275269, 6575, 2248, 51, 1, "Input",ExpressionUUID->"4e439ab6-a6bd-44d0-81ba-a702a5d16007",
 CellOpen->False],
Cell[277520, 6628, 2958, 89, 89, "Text",ExpressionUUID->"0a2facfe-3b91-492e-b94c-43d4c47691b6"],
Cell[280481, 6719, 201, 5, 23, "Caption",ExpressionUUID->"a27721a8-5d8e-4a92-a0a5-fa0e452f479e"],
Cell[280685, 6726, 707, 16, 82, "Text",ExpressionUUID->"58fe7460-a42b-464e-9f4f-21c5e8e91bb6"],
Cell[CellGroupData[{
Cell[281417, 6746, 549, 13, 91, "Input",ExpressionUUID->"a7249185-988d-40bb-a787-28ec4b72d3d5"],
Cell[281969, 6761, 191, 3, 36, "Output",ExpressionUUID->"75db34ba-bf11-4e4d-a0b6-17d8224abd08"],
Cell[282163, 6766, 189, 3, 36, "Output",ExpressionUUID->"d186671c-f0ab-4866-995e-682a1e8ab5b8"],
Cell[282355, 6771, 182, 3, 36, "Output",ExpressionUUID->"18566d81-0f01-444e-908f-9ed8ef4cf92c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[282574, 6779, 529, 15, 64, "Input",ExpressionUUID->"29e895de-815a-4c7f-966f-5efee9433091"],
Cell[283106, 6796, 186, 3, 36, "Output",ExpressionUUID->"bd9aecbb-4b49-49b7-93ba-6874a1b630c9"],
Cell[283295, 6801, 189, 3, 36, "Output",ExpressionUUID->"fb1400d7-0f9d-4f27-b1c8-dc123eab594a"]
}, Open  ]],
Cell[283499, 6807, 1599, 43, 132, "Text",ExpressionUUID->"3227fc29-b148-4bc1-91a9-75edbddbd20c"],
Cell[CellGroupData[{
Cell[285123, 6854, 574, 15, 91, "Input",ExpressionUUID->"3b498a16-f41e-4c8a-8dca-c0b37d14e5df"],
Cell[285700, 6871, 261, 4, 36, "Output",ExpressionUUID->"8a693d9c-b1c0-4e51-988e-f9190690d2dd"],
Cell[285964, 6877, 260, 4, 36, "Output",ExpressionUUID->"b8e325cc-085f-4f14-9885-ada74da6d1c9"],
Cell[286227, 6883, 260, 4, 36, "Output",ExpressionUUID->"38cfa0c5-9daf-451a-bb07-9c77fa43cff7"]
}, Open  ]],
Cell[286502, 6890, 1071, 36, 83, "Text",ExpressionUUID->"5e0a3223-55d4-4121-8df0-d16e1b3bdb9c"],
Cell[287576, 6928, 416, 7, 34, "Text",ExpressionUUID->"afcfb616-e12b-4107-a632-bcf3831552bb"]
}, Open  ]]
}
]
*)

